@@ -1,38 +1,61 @@
-#!/bin/bash
+#!/usr/bin/env bash
 #
 # Project    : ipv6calc
 # File       : autogen-all-variants.sh
-# Version    : $Id: 865c74c6660aa5d4bf22cda0b17b59949bf85c05 $
-# Copyright  : 2011-2019 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: 7d33a8c898f4320bac72e940eeb50ab9a2927c2c $
+# Copyright  : 2011-2021 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Information: run autogen.sh with all supported variants
 #
-# can run also through various version of GeoIP (-g) and IP2Location (-i) libraries
+# history: can run also through various version of GeoIP (-g) and IP2Location (-i) libraries
 #  see autogen-support.sh for details
 
 status_file="autogen-all-variants.status"
 
 ## Generate configure variants
 autogen_variants() {
-	if [ "$skip_main_test" != "1" ]; then
+	autogen_variants_list
+	autogen_variants_list | while IFS="#" read options list; do
+		echo "${options:+$options }--clang#$list"
+	done
+
+	autogen_variants_list | while IFS="#" read options list; do
+		echo "${options:+$options }--gcc-Os#$list"
+	done
+
+	case "$OSTYPE" in
+	    freebsd*)
+		    # skip 32-bit builds on freebsd
+		    return
+		    ;;
+	esac
+
+	# skip IP2Location and MaxMindDB based
+	autogen_variants_list | grep -Evw "(IP2LOCATION|GEOIP2|DBIP2)" | while IFS="#" read options list; do
+		echo "${options:+$options }--m32#$list"
+	done
+	autogen_variants_list | grep -Evw "(IP2LOCATION|GEOIP2|DBIP2)" | while IFS="#" read options list; do
+		echo "${options:+$options }--clang --m32#$list"
+	done
+}
+
+autogen_variants_list() {
+	if ! $skip_main_test; then
 		cat <<END | grep -v ^#
 NONE#
-NONE#--enable-bundled-md5 --enable-bundled-getopt
-DBIP#-d
+BUNDLED#--enable-bundled-md5 --enable-bundled-getopt
+OPENSSL#--enable-openssl-md5
+OPENSSL#--enable-openssl-evp-md5
 IP2LOCATION#-i
 IP2LOCATION#-i --ip2location-dyn
-GEOIP#-g
-GEOIP#-g --geoip-dyn
-GEOIP#-g --geoip-ipv6-compat
-GEOIP#-g --geoip-ipv6-compat --geoip-dyn
 GEOIP2 DBIP2#-m
 GEOIP2 DBIP2#-m --mmdb-dyn
 GEOIP2#-m --disable-dbip2
 GEOIP2#-M --disable-dbip2
 DBIP2#-m --disable-geoip2
 DBIP2#-M --disable-geoip2
-IP2LOCATION GEOIP DBIP GEOIP2 DBIP2#-a
-IP2LOCATION GEOIP DBIP GEOIP2 DBIP2#-A
+IP2LOCATION GEOIP2 DBIP2#-a
+IP2LOCATION GEOIP2 DBIP2#-A
 NONE#--disable-db-ieee
 NONE#--disable-db-ipv4
 NONE#--disable-db-ipv6
@@ -43,10 +66,11 @@ NONE#--disable-db-ipv6 --disable-db-ipv4 --disable-db-ieee --disable-cc-registry
 NONE#--disable-db-ipv6 --disable-db-ipv4 --disable-db-ieee --disable-as-registry --disable-cc-registry
 NONE#--disable-db-ipv6 --disable-db-ieee
 NONE#--disable-db-ipv4 --disable-db-ieee
+NONE#--disable-db-builtin
 END
 	fi
 
-	if [ "$ip2location_versions_test" = "1" ]; then
+	if $ip2location_versions_test; then
 		for version in $ip2location_versions; do
 			[ ${version:0:1} = "!" ] && continue
 			local testlist=""
@@ -63,28 +87,7 @@ END
 					fi
 				fi
 			done
-			echo "NONE#--enable-ip2location $option $(options_from_name_version IP2Location $version)#$testlist"
-		done
-	fi
-
-	if [ "$geoip_versions_test" = "1" ]; then
-		for version in $geoip_versions; do
-			[ ${version:0:1} = "!" ] && continue
-			local testlist=""
-			local option=""
-			for version_test in $geoip_versions; do
-				if [ "$dynamic_load" = "1" ]; then
-					option="--geoip-dyn"
-					# unconditionally test all versions
-					testlist="$testlist G:$version_test"
-				else
-					[ ${version_test:0:1} = "!" ] && continue
-					if geoip_cross_version_test_blacklist $version $version_test; then
-						testlist="$testlist G:$version_test"
-					fi
-				fi
-			done
-			echo "NONE#--enable-geoip $option $(options_from_name_version GeoIP $version)#$testlist"
+			echo "IP2LOCATION#--enable-ip2location $option $(options_from_name_version IP2Location $version)#$testlist"
 		done
 	fi
 }
@@ -97,54 +100,60 @@ $0
 	-r	force re-run, after finished one, remove status file
 	-N	add --no-static-build to autogen.sh
 	-I	skip IP2Location builds using system wide available library
-	-G	skip GeoIP builds using system wide available library
-	-g	run through internal defined GeoIP versions
 	-i	run through internal defined IP2Location versions
 	-D	enable dynamic library loading in run through versions	
 	-M	skip main tests
 	-n	dry-run, show only what would be build
+	-c	cross version test
+	-b	batch test (do not stop on error)
 END
 }
 
 
-while getopts ":cDNMigrIGfWn?h" opt; do
+batch=false
+cross_versions_test=false
+dry_run=false
+dynamic_load=false
+force=false
+no_static_build=false
+rerun=false
+skip_main_test=false
+skip_shared=false
+ip2location_versions_test=false
+
+while getopts ":cbDNMirIfWn?h" opt; do
 	case $opt in
+	    'b')
+		batch=true
+		;;
 	    'f')
-		force=1
+		force=true
 		;;
 	    'r')
-		rerun=1
+		rerun=true
 		;;
 	    'N')
-		no_static_build=1
+		no_static_build=true
 		;;
 	    'n')
-		dry_run=1
+		dry_run=true
 		;;
 	    'M')
-		skip_main_test=1
+		skip_main_test=true
 		;;
 	    'I')
 		skip_token="IP2LOCATION"
 		;;
-	    'G')
-		skip_token="GEOIP"
-		;;
-	    'g')
-		geoip_versions_test="1"
-		skip_shared="1"
-		no_static_build=1
-		;;
 	    'i')
-		ip2location_versions_test="1"
-		skip_shared="1"
-		no_static_build=1
+		ip2location_versions_test=true
+		skip_shared=true
+		no_static_build=true
 		;;
 	    'c')
-		cross_versions_test="1"
+		cross_versions_test=true
 		;;
 	    'D')
-		dynamic_load="1"
+		dynamic_load=true
 		;;
 	    \?|h)
 		help
@@ -165,15 +174,15 @@ if [ -n "$options_add" ]; then
 	echo "INFO  : additional options: $options_add"
 fi
 
-if [ -f "$status_file" -a "$dry_run" != "1" ]; then
+if [ -f "$status_file" ] && ! $dry_run; then
 	echo "INFO  : status file found: $status_file"
 
-	if [ "$force" = "1" ]; then
+	if $force; then
 		echo "NOTICE: remove status file (force)"
 		rm $status_file
 	else
 		if grep -q ":END:" $status_file; then
-			if [ "$rerun" = "1" ]; then
+			if $rerun; then
 				echo "NOTICE: all runs successful, option -r given, status file removed (re-run)"
 				rm $status_file
 			else
@@ -181,7 +190,7 @@ if [ -f "$status_file" -a "$dry_run" != "1" ]; then
 				exit 0
 			fi
 		else
-			if [ "$rerun" = "1" ]; then
+			if $rerun; then
 				echo "NOTICE: option -r for forcing a re-run is useless, last run was not finished (use -f)"
 				exit 0
 			fi
@@ -189,10 +198,10 @@ if [ -f "$status_file" -a "$dry_run" != "1" ]; then
 	fi
 fi
 
-if [ "$dry_run" != "1" ]; then
+if ! $dry_run; then
 	if [ ! -f "$status_file" ]; then
 		echo "INFO  : status file missing, create: $status_file"
-		date "+%s:START:" >$status_file
+		date "+%s:START:${batch:+BATCHMODE}" >$status_file
 	fi
 fi
 
@@ -205,19 +214,30 @@ fi
 
 # variants
 for liboption in "normal" "shared"; do
-	if [ "$skip_shared" = "1" -a "$liboption" = "shared" ]; then
+	if $skip_shared  && [ "$liboption" = "shared" ]; then
 		continue
 	fi
 
 	autogen_variants | while IFS="#" read token buildoptions testlist; do
+		case "$OSTYPE" in
+		    freebsd*)
+			case $token in
+			    BUNDLED)
+				echo "NOTICE: disable on OSTYPE=$OSTYPE: $buildoptions"
+				continue
+				;;
+			esac
+		esac
+
+		buildoptions=$(echo $buildoptions)
 		if [ -n "$options_add" ]; then
-			if [ "$no_static_build" = "1" ]; then
+			if $no_static_build; then
 				options="--no-static-build $options_add $buildoptions"
 			else
-				options="$options_add $buildoptions"
+				options="${options_add:+$options_add }$buildoptions"
 			fi
 		else
-			if [ "$no_static_build" = "1" ]; then
+			if $no_static_build; then
 				options="--no-static-build $buildoptions"
 			else
 				options="$buildoptions"
@@ -226,27 +246,21 @@ for liboption in "normal" "shared"; do
 
 		case $liboption in
 		    shared)
-			options="$options -S"
+			options="${options:+$options }-S"
 			;;
 		esac
 
 		# extend options in fallback case
 		if [ -n "$ip2location_options_extra" ]; then
-			if echo "$token" | egrep -wq "IP2LOCATION"; then
-				options="$options $ip2location_options_extra"
-			fi
-		fi
-
-		if [ -n "$geoip_options_extra" ]; then
-			if echo "$token" | egrep -wq "GEOIP"; then
-				options="$options $geoip_options_extra"
+			if echo "$token" | grep -Fwq "IP2LOCATION"; then
+				options="${options:+$options }$ip2location_options_extra"
 			fi
 		fi
 
 		# check for already executed option combination
 		if [ -f "$status_file" ]; then
 			if [ -z "$testlist" ]; then
-				if egrep -q ":FINISHED:variants:$options:" $status_file; then
+				if grep -Eq ":FINISHED:variants:$options:" $status_file; then
 					echo "NOTICE: skip variant run (already finished) with: $options"
 					continue
 				fi
@@ -255,9 +269,9 @@ for liboption in "normal" "shared"; do
 			fi
 		fi
 
-		if echo "$token" | egrep -wq "$skip_token"; then
+		if echo "$token" | grep -Ewq "$skip_token"; then
 			echo "NOTICE: skip variant because of token: $token"
-			if [ "$dry_run" = "1" ]; then
+			if $dry_run; then
 				date "+%s:FINISHED:variants:$options:SKIPPED" >>$status_file
 			fi
 			continue
@@ -269,7 +283,7 @@ for liboption in "normal" "shared"; do
 			options_test="--no-test"
 		fi
 
-		if [ "$dry_run" = "1" ]; then
+		if $dry_run; then
 			echo "INFO  : would call(dry-run): ./autogen.sh $options_test $options"
 			if [ -z "$testlist" ]; then
 				continue
@@ -281,18 +295,25 @@ for liboption in "normal" "shared"; do
 			nice -n 20 $IONICE ./autogen.sh $options_test $options
 			if [ $? -ne 0 ]; then
 				echo "ERROR : autogen.sh reports an error with options: $options_test $options"
-				exit 1
+				if $batch; then
+					date "+%s:BROKEN:variants:$options" >>$status_file
+				else
+					exit 1
+				fi
+			else
+				# add entry in log
+				date "+%s:FINISHED:variants:$options:OK" >>$status_file
 			fi
 		fi
 
 		if [ -n "$testlist" ]; then
 			for entry in $testlist; do
-				if egrep -q ":FINISHED:variants:$options:TESTLIST-ENTRY=$entry" $status_file; then
+				if grep -Eq ":FINISHED:variants:$options:TESTLIST-ENTRY=$entry" $status_file; then
 					echo "NOTICE: skip variant test (already finished) with: $options and $entry"
 					continue
 				fi
 
-				if [ "$dry_run" = "1" ]; then
+				if $dry_run; then
 					echo "INFO  : would call(dry-run): ./autogen.sh $options (testlist entry: $entry)"
 					continue
 				fi
@@ -322,7 +343,7 @@ for liboption in "normal" "shared"; do
 					exit 1
 				fi
 
-				if [ "$dynamic_load" = "1" ]; then
+				if $dynamic_load; then
 					case $name in
 					    I*)
 						feature_string="IP2Location"
@@ -340,41 +361,49 @@ for liboption in "normal" "shared"; do
 					fi
 
 					echo "INFO  : call: LD_LIBRARY_PATH=$libdir make test-ldlibpath"
-					LD_LIBRARY_PATH="$libdir" make test-ldlibpath
+					LD_LIBRARY_PATH="$libdir" $MAKE test-ldlibpath
 					result=$?
 				else
 					echo "INFO  : call: LD_PRELOAD=$lib make test-ldlibpath"
-					LD_LIBRARY_PATH="$libdir" make test-ldlibpath
+					LD_LIBRARY_PATH="$libdir" $MAKE test-ldlibpath
 					result=$?
 				fi
 
 				if [ $result -ne 0 ]; then
 					echo "ERROR : autogen.sh reports an error with options: $options during testlist entry: $entry"
-					if [ "$dynamic_load" = "1" ]; then
+					if $dynamic_load; then
 						echo "NOTICE: executed command: LD_LIBRARY_PATH=$libdir make test-ldlibpath"
 					else
 						echo "NOTICE: executed command: LD_PRELOAD="$lib" make test-ldlibpath"
 					fi
-					exit 1
-				fi
 
-				date "+%s:FINISHED:variants:$options:TESTLIST-ENTRY=$entry" >>$status_file
+					if $batch; then
+						date "+%s:BROKEN:variants:$options:TESTLIST-ENTRY=$entry" >>$status_file
+					else
+						exit 1
+					fi
+				else
+					date "+%s:FINISHED:variants:$options:TESTLIST-ENTRY=$entry" >>$status_file
+				fi
 			done
 		fi
 
-		# add entry in log
-		date "+%s:FINISHED:variants:$options:OK" >>$status_file
-
 	done || exit 1
 done
 
 
-if [ "$dry_run" != "1" ]; then
-	echo "INFO  : congratulations, all variants built successful!"
+if ! $dry_run; then
+	if grep -q ":BROKEN:" $status_file; then
+		echo "ERROR : there are BROKEN builds:"
+		grep ":BROKEN:" $status_file
+		exit 1
+	else
+		echo "INFO  : congratulations, all variants built successful!"
+	fi
 	date "+%s:END:" >>$status_file
 	cat $status_file
 
-	make autoclean >/dev/null 
+	$MAKE autoclean >/dev/null
 	if [ $? -ne 0 ]; then
 		echo "ERROR : 'make autoclean' failed"
 		exit 1
