@@ -1,15 +1,15 @@
  /*
  * Project       : ipv6calc
  * File          : db_cc_reg_assignment.h
- * Version       : $Id: 38c272e1ad303ec7970598929af05ca3c0c3e96c $
- * Generated     : Fri Apr  5 06:02:52 2019
+ * Version       : $Id: ddf5ff9cb83d18d7f345991badd3c6cc8ccce974 $
+ * Generated     : Tue Jan 25 22:06:14 2022
  * Data copyright: RIPE NCC, APNIC, ARIN, LACNIC, AFRINIC
  *
  * Information:
  *  Additional header file for databases/lib/libipv6calc_db_wrapper_BuiltIn.c
  */
 
-static const char *db_cc_registry_status = "AFRINIC/20190403 APNIC/20190404 ARIN/20190404 LACNIC/20190404 RIPENCC/20190404";
+static const char *db_cc_registry_status = "AFRINIC/20220124 APNIC/20220125 ARIN/20220125 LACNIC/20220121 RIPENCC/20220124";
 
 static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "", REGISTRY_ARIN     },
@@ -21,8 +21,6 @@ static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "AL", REGISTRY_RIPENCC  },
 	{ "AM", REGISTRY_RIPENCC  },
 	{ "AO", REGISTRY_AFRINIC  },
-	{ "AP", REGISTRY_APNIC    },
-	{ "AQ", REGISTRY_ARIN     },
 	{ "AR", REGISTRY_LACNIC   },
 	{ "AS", REGISTRY_APNIC    },
 	{ "AT", REGISTRY_RIPENCC  },
@@ -49,7 +47,7 @@ static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "BT", REGISTRY_APNIC    },
 	{ "BW", REGISTRY_AFRINIC  },
 	{ "BY", REGISTRY_RIPENCC  },
-	{ "BZ", REGISTRY_LACNIC   },
+	{ "BZ", REGISTRY_RIPENCC  },
 	{ "CA", REGISTRY_ARIN     },
 	{ "CD", REGISTRY_AFRINIC  },
 	{ "CF", REGISTRY_AFRINIC  },
@@ -202,7 +200,7 @@ static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "RW", REGISTRY_AFRINIC  },
 	{ "SA", REGISTRY_RIPENCC  },
 	{ "SB", REGISTRY_APNIC    },
-	{ "SC", REGISTRY_AFRINIC  },
+	{ "SC", REGISTRY_RIPENCC  },
 	{ "SD", REGISTRY_AFRINIC  },
 	{ "SE", REGISTRY_RIPENCC  },
 	{ "SG", REGISTRY_APNIC    },
@@ -242,14 +240,14 @@ static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "VA", REGISTRY_RIPENCC  },
 	{ "VC", REGISTRY_ARIN     },
 	{ "VE", REGISTRY_LACNIC   },
-	{ "VG", REGISTRY_ARIN     },
+	{ "VG", REGISTRY_RIPENCC  },
 	{ "VI", REGISTRY_ARIN     },
 	{ "VN", REGISTRY_APNIC    },
 	{ "VU", REGISTRY_APNIC    },
 	{ "WF", REGISTRY_APNIC    },
 	{ "WS", REGISTRY_APNIC    },
 	{ "YE", REGISTRY_RIPENCC  },
-	{ "YT", REGISTRY_AFRINIC  },
+	{ "YT", REGISTRY_RIPENCC  },
 	{ "ZA", REGISTRY_AFRINIC  },
 	{ "ZM", REGISTRY_AFRINIC  },
 	{ "ZW", REGISTRY_AFRINIC  },
@@ -586,7 +584,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  327  PC
 	{ REGISTRY_UNKNOWN  }, //  328  QC
 	{ REGISTRY_UNKNOWN  }, //  329  RC
-	{ REGISTRY_AFRINIC  }, //  330  SC
+	{ REGISTRY_RIPENCC  }, //  330  SC
 	{ REGISTRY_ARIN     }, //  331  TC
 	{ REGISTRY_UNKNOWN  }, //  332  UC
 	{ REGISTRY_ARIN     }, //  333  VC
@@ -693,7 +691,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_APNIC    }, //  434  SG
 	{ REGISTRY_AFRINIC  }, //  435  TG
 	{ REGISTRY_AFRINIC  }, //  436  UG
-	{ REGISTRY_ARIN     }, //  437  VG
+	{ REGISTRY_RIPENCC  }, //  437  VG
 	{ REGISTRY_UNKNOWN  }, //  438  WG
 	{ REGISTRY_UNKNOWN  }, //  439  XG
 	{ REGISTRY_UNKNOWN  }, //  440  YG
@@ -906,7 +904,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  647  XO
 	{ REGISTRY_UNKNOWN  }, //  648  YO
 	{ REGISTRY_UNKNOWN  }, //  649  ZO
-	{ REGISTRY_APNIC    }, //  650  AP
+	{ REGISTRY_UNKNOWN  }, //  650  AP
 	{ REGISTRY_UNKNOWN  }, //  651  BP
 	{ REGISTRY_UNKNOWN  }, //  652  CP
 	{ REGISTRY_UNKNOWN  }, //  653  DP
@@ -932,7 +930,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  673  XP
 	{ REGISTRY_UNKNOWN  }, //  674  YP
 	{ REGISTRY_UNKNOWN  }, //  675  ZP
-	{ REGISTRY_ARIN     }, //  676  AQ
+	{ REGISTRY_UNKNOWN  }, //  676  AQ
 	{ REGISTRY_LACNIC   }, //  677  BQ
 	{ REGISTRY_UNKNOWN  }, //  678  CQ
 	{ REGISTRY_UNKNOWN  }, //  679  DQ
@@ -1034,7 +1032,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  775  VT
 	{ REGISTRY_UNKNOWN  }, //  776  WT
 	{ REGISTRY_UNKNOWN  }, //  777  XT
-	{ REGISTRY_AFRINIC  }, //  778  YT
+	{ REGISTRY_RIPENCC  }, //  778  YT
 	{ REGISTRY_UNKNOWN  }, //  779  ZT
 	{ REGISTRY_APNIC    }, //  780  AU
 	{ REGISTRY_UNKNOWN  }, //  781  BU
@@ -1167,7 +1165,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  908  YY
 	{ REGISTRY_UNKNOWN  }, //  909  ZY
 	{ REGISTRY_RIPENCC  }, //  910  AZ
-	{ REGISTRY_LACNIC   }, //  911  BZ
+	{ REGISTRY_RIPENCC  }, //  911  BZ
 	{ REGISTRY_RIPENCC  }, //  912  CZ
 	{ REGISTRY_AFRINIC  }, //  913  DZ
 	{ REGISTRY_UNKNOWN  }, //  914  EZ
