@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper.h
- * Version    : $Id: 39126b6a85ac84639bccd67cff1774cd332e8885 $
- * Copyright  : 2013-2019 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 7dc27180e82742324f3c536dbabe3c1a67a3f350 $
+ * Copyright  : 2013-2021 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Header file for libipv6calc_db_wrapper.c
@@ -12,15 +12,19 @@
 #include <db.h>
 #endif // HAVE_BERKELEY_DB_SUPPORT
 
-#include "ipv6calctypes.h"
-#include "libmac.h"
-#include "libipv4addr.h"
-#include "libipv6addr.h"
-
 #ifndef _libipv6calc_db_wrapper_h
 
 #define _libipv6calc_db_wrapper_h 1
 
+
+#include "libmac.h"
+#include "libipv4addr.h"
+#include "libipv6addr.h"
+#include "libipaddr.h"
+#include "ipv6calctypes.h"
+#include "libipv6calc_filter.h"
+
+
 extern uint32_t wrapper_features;
 extern uint32_t wrapper_features_by_source[];
 extern uint32_t wrapper_features_by_source_implemented[];
@@ -49,36 +53,41 @@ extern uint32_t wrapper_features_by_source_implemented[];
 #define IPV6CALC_DB_FEATURE_NUM_IPV6_TO_INFO		16
 #define IPV6CALC_DB_FEATURE_NUM_IPV4_TO_GEONAMEID	17
 #define IPV6CALC_DB_FEATURE_NUM_IPV6_TO_GEONAMEID	18
-#define IPV6CALC_DB_FEATURE_NUM_MAX			IPV6CALC_DB_FEATURE_NUM_IPV6_TO_GEONAMEID
+#define IPV6CALC_DB_FEATURE_NUM_IPV4_DUMP_CC		19
+#define IPV6CALC_DB_FEATURE_NUM_IPV6_DUMP_CC		20
+#define IPV6CALC_DB_FEATURE_NUM_MAX			IPV6CALC_DB_FEATURE_NUM_IPV6_DUMP_CC
 
 // define generic features
-#define IPV6CALC_DB_AS_TO_REGISTRY		(1 << IPV6CALC_DB_FEATURE_NUM_AS_TO_REGISTRY)
-#define IPV6CALC_DB_CC_TO_REGISTRY		(1 << IPV6CALC_DB_FEATURE_NUM_CC_TO_REGISTRY)
-#define IPV6CALC_DB_IPV4_TO_REGISTRY		(1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_REGISTRY)
-#define IPV6CALC_DB_IPV6_TO_REGISTRY		(1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_REGISTRY)
+#define IPV6CALC_DB_AS_TO_REGISTRY		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_AS_TO_REGISTRY)
+#define IPV6CALC_DB_CC_TO_REGISTRY		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_CC_TO_REGISTRY)
+#define IPV6CALC_DB_IPV4_TO_REGISTRY		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_REGISTRY)
+#define IPV6CALC_DB_IPV6_TO_REGISTRY		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_REGISTRY)
 
-#define IPV6CALC_DB_IPV4_TO_AS			(1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_AS)
-#define IPV6CALC_DB_IPV6_TO_AS			(1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_AS)
+#define IPV6CALC_DB_IPV4_TO_AS			((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_AS)
+#define IPV6CALC_DB_IPV6_TO_AS			((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_AS)
 
-#define IPV6CALC_DB_IPV4_TO_CC			(1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_CC)
-#define IPV6CALC_DB_IPV6_TO_CC			(1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_CC)
+#define IPV6CALC_DB_IPV4_TO_CC			((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_CC)
+#define IPV6CALC_DB_IPV6_TO_CC			((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_CC)
 
-#define IPV6CALC_DB_IPV4_TO_COUNTRY		(1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_COUNTRY)
-#define IPV6CALC_DB_IPV6_TO_COUNTRY		(1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_COUNTRY)
+#define IPV6CALC_DB_IPV4_TO_COUNTRY		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_COUNTRY)
+#define IPV6CALC_DB_IPV6_TO_COUNTRY		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_COUNTRY)
 
-#define IPV6CALC_DB_IPV4_TO_CITY		(1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_CITY)
-#define IPV6CALC_DB_IPV6_TO_CITY		(1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_CITY)
+#define IPV6CALC_DB_IPV4_TO_CITY		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_CITY)
+#define IPV6CALC_DB_IPV6_TO_CITY		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_CITY)
 
-#define IPV6CALC_DB_IPV4_TO_REGION		(1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_REGION)
-#define IPV6CALC_DB_IPV6_TO_REGION		(1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_REGION)
+#define IPV6CALC_DB_IPV4_TO_REGION		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_REGION)
+#define IPV6CALC_DB_IPV6_TO_REGION		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_REGION)
 
-#define IPV6CALC_DB_IEEE_TO_INFO		(1 << IPV6CALC_DB_FEATURE_NUM_IEEE_TO_INFO)
+#define IPV6CALC_DB_IEEE_TO_INFO		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IEEE_TO_INFO)
 
-#define IPV6CALC_DB_IPV4_TO_INFO		(1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_INFO)
-#define IPV6CALC_DB_IPV6_TO_INFO		(1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_INFO)
+#define IPV6CALC_DB_IPV4_TO_INFO		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_INFO)
+#define IPV6CALC_DB_IPV6_TO_INFO		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_INFO)
 
-#define IPV6CALC_DB_IPV4_TO_GEONAMEID		(1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_GEONAMEID)
-#define IPV6CALC_DB_IPV6_TO_GEONAMEID		(1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_GEONAMEID)
+#define IPV6CALC_DB_IPV4_TO_GEONAMEID		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV4_TO_GEONAMEID)
+#define IPV6CALC_DB_IPV6_TO_GEONAMEID		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV6_TO_GEONAMEID)
+
+#define IPV6CALC_DB_IPV4_DUMP_CC		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV4_DUMP_CC)
+#define IPV6CALC_DB_IPV6_DUMP_CC		((uint32_t) 1 << IPV6CALC_DB_FEATURE_NUM_IPV6_DUMP_CC)
 
 // define combination of generic features
 #define IPV6CALC_DB_IP_TO_AS			(IPV6CALC_DB_IPV4_TO_AS        | IPV6CALC_DB_IPV6_TO_AS       )
@@ -125,11 +134,13 @@ static const s_formatoption ipv6calc_db_features[] = {
 	{ IPV6CALC_DB_IPV4_TO_REGION	, "DB_IPV4_REGION"	, "IPv4 to Region database" },
 	{ IPV6CALC_DB_IPV6_TO_REGION	, "DB_IPV6_REGION"	, "IPv6 to Region database" },
 	{ IPV6CALC_DB_CC_TO_REGISTRY	, "DB_CC_REG"		, "CountryCode to Registry database" },
-	{ IPV6CALC_DB_IEEE_TO_INFO	, "DB_IEEE"		, "IEEE/OUI/OUI36 Vendor database" },
+	{ IPV6CALC_DB_IEEE_TO_INFO	, "DB_IEEE"		, "IEEE/OUI/OUI28/OUI36 Vendor database" },
 	{ IPV6CALC_DB_IPV4_TO_INFO	, "DB_IPV4_INFO"	, "IPv4 additional information" },
 	{ IPV6CALC_DB_IPV6_TO_INFO	, "DB_IPV6_INFO"	, "IPv6 additional information" },
 	{ IPV6CALC_DB_IPV4_TO_GEONAMEID	, "DB_IPV4_GEONAMEID"	, "IPv4 GeonameID" },
 	{ IPV6CALC_DB_IPV6_TO_GEONAMEID	, "DB_IPV6_GEONAMEID"	, "IPv6 GeonameID" },
+	{ IPV6CALC_DB_IPV4_DUMP_CC	, "DB_IPV4_DUMP_CC"	, "IPv4 Database Dump by CountryCode" },
+	{ IPV6CALC_DB_IPV6_DUMP_CC	, "DB_IPV6_DUMP_CC"	, "IPv6 Database Dump by CountryCode" },
 };
 
 // data sources
@@ -379,6 +390,7 @@ extern const char *libipv6calc_db_wrapper_get_data_source_name_by_number(const u
 // CountryCode Text/Number
 extern int         libipv6calc_db_wrapper_country_code_by_addr(char *string, const int length, const ipv6calc_ipaddr *ipaddrp, unsigned int *data_source_ptr);
 extern int         libipv6calc_db_wrapper_country_code_by_cc_index(char *string, const int length, const uint16_t cc_index);
+extern uint16_t    libipv6calc_db_wrapper_cc_index_by_country_code(const char *cc_text);
 extern uint16_t    libipv6calc_db_wrapper_cc_index_by_addr(const ipv6calc_ipaddr *ipaddrp, unsigned int *data_source_ptr);
 
 // Autonomous System Text/Number
@@ -415,6 +427,18 @@ extern void libipv6calc_db_wrapper_geolocation_record_clear(libipv6calc_db_wrapp
 
 #ifdef HAVE_BERKELEY_DB_SUPPORT
 extern int libipv6calc_db_wrapper_bdb_get_data_by_key(DB *dbp, char *token, char *value, const size_t value_size);
+
+// fetch row
+extern int libipv6calc_db_wrapper_bdb_fetch_row(
+	DB 			*db_ptr,		// pointer to DB
+	const uint8_t		db_format,		// DB format
+	const long int		row,			// row number
+	uint32_t		*data_1_00_31_ptr,	// data 1 (MSB in case of 64 bits)
+	uint32_t		*data_1_32_63_ptr,	// data 1 (LSB in case of 64 bits)
+	uint32_t		*data_2_00_31_ptr,	// data 2 (MSB in case of 64 bits)
+	uint32_t		*data_2_32_63_ptr,	// data 2 (LSB in case of 64 bits)
+	void			*data_ptr		// pointer to data
+	);
 #endif // HAVE_BERKELEY_DB_SUPPORT
 
 // generic DB lookup
@@ -445,6 +469,8 @@ extern int libipv6calc_db_registry_filter_parse(s_ipv6calc_filter_db_registry *f
 extern int libipv6calc_db_registry_filter_check(const s_ipv6calc_filter_db_registry *filter, const int proto);
 extern int libipv6calc_db_registry_filter(const uint32_t registry, const s_ipv6calc_filter_db_registry *filter);
 
+extern int libipv6calc_db_dump(const int source, const int selector, const s_ipv6calc_filter_master *filter_master, const uint32_t outputtype, const uint32_t formatoptions, const char *name_ipset);
+
 extern       uint32_t libipv6calc_db_lib_version_numeric(void);
 extern const char    *libipv6calc_db_lib_version_string(void);
 extern       uint32_t libipv6calc_db_api_version_numeric(void);
