@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_DBIP2.c
- * Version    : $Id: e60259ddda7ae35e00c3419db170e065823754fa $
- * Copyright  : 2019-2019 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 0374cfb1ce43b164edceb1589fc54204b56cae50 $
+ * Copyright  : 2019-2021 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  ipv6calc DB-IP.com database wrapper for MaxMindDB databases
@@ -26,15 +26,64 @@
 
 #ifdef SUPPORT_DBIP2
 
-#include <db.h>
-
 #include "libipv6calc_db_wrapper_DBIP2.h"
 
-char dbip2_db_dir[NI_MAXHOST] = DBIP2_DB;
+char dbip2_db_dir[PATH_MAX] = DBIP2_DB;
 
 static const char* wrapper_dbip2_info = "DBIP2";
 
 
+/* database files */
+static const db_file_desc2 libipv6calc_db_wrapper_DBIP2_db_file_desc[] = {
+	// country (lite)
+	{ DBIP2_DB_COUNTRY_LITE
+		, "dbip-country-lite.mmdb"
+		, "IPv4/v6 CountryCode (FREE)"
+		, IPV6CALC_DB_IP_TO_CC | IPV6CALC_DB_DBIP | IPV6CALC_DB_IP_TO_GEONAMEID | IPV6CALC_DB_IP_TO_COUNTRY
+		, IPV6CALC_DB_DBIP2_INTERNAL_FREE
+	},
+
+	// city (lite)
+	{ DBIP2_DB_CITY_LITE
+		, "dbip-city-lite.mmdb"
+		, "IPv4/v6 City (FREE)"
+		, IPV6CALC_DB_IP_TO_CITY | IPV6CALC_DB_IP_TO_REGION | IPV6CALC_DB_IP_TO_CC | IPV6CALC_DB_DBIP | IPV6CALC_DB_IP_TO_GEONAMEID | IPV6CALC_DB_IP_TO_COUNTRY
+		, IPV6CALC_DB_DBIP2_INTERNAL_FREE
+	},
+
+	// country
+	{ DBIP2_DB_COUNTRY
+		, "dbip-country.mmdb"
+		, "IPv4/v6 CountryCode (COMM)"
+		, IPV6CALC_DB_IP_TO_CC | IPV6CALC_DB_DBIP | IPV6CALC_DB_IP_TO_GEONAMEID | IPV6CALC_DB_IP_TO_COUNTRY
+		, IPV6CALC_DB_DBIP2_INTERNAL_COMM
+	},
+
+	// location
+	{ DBIP2_DB_LOCATION
+		, "dbip-location.mmdb"
+		, "IPv4/v6 Location (COMM)"
+		, IPV6CALC_DB_IP_TO_CITY | IPV6CALC_DB_IP_TO_REGION | IPV6CALC_DB_IP_TO_CC | IPV6CALC_DB_DBIP | IPV6CALC_DB_IP_TO_COUNTRY | IPV6CALC_DB_IP_TO_GEONAMEID
+		, IPV6CALC_DB_DBIP2_INTERNAL_COMM
+	},
+
+	// ISP
+	{ DBIP2_DB_ISP
+		, "dbip-isp.mmdb"
+		, "IPv4/v6 ISP (COMM)", IPV6CALC_DB_IP_TO_CC | IPV6CALC_DB_DBIP | IPV6CALC_DB_IP_TO_AS
+		, IPV6CALC_DB_DBIP2_INTERNAL_COMM
+	},
+
+	// full
+	{ DBIP2_DB_LOCATION_ISP
+		, "dbip-location-isp.mmdb"
+		, "IPv4/v6 Location+ISP (COMM)"
+		, IPV6CALC_DB_IP_TO_CITY | IPV6CALC_DB_IP_TO_REGION | IPV6CALC_DB_IP_TO_CC | IPV6CALC_DB_DBIP | IPV6CALC_DB_IP_TO_COUNTRY | IPV6CALC_DB_IP_TO_AS | IPV6CALC_DB_IP_TO_GEONAMEID
+		, IPV6CALC_DB_DBIP2_INTERNAL_COMM
+	},
+};
+
+
 // DB used for resolution after automatic election, which is currently done by checking for DB files and the sequence in the header file
 static int dbip2_db_country_v4 = 0;
 static int dbip2_db_country_v6 = 0;
@@ -83,7 +132,7 @@ static uint32_t dbip2_db_usage_map[DBIP2_DB_MAX_BLOCKS_32];
 							exit(1); \
 						};
 
-char dbip2_db_usage_string[NI_MAXHOST] = "";
+char dbip2_db_usage_string[IPV6CALC_STRING_MAX] = "";
 
 // local cache
 static MMDB_s mmdb_cache[DBIP2_DB_MAX+1];
@@ -444,7 +493,7 @@ void libipv6calc_db_wrapper_DBIP2_wrapper_print_db_info(const int level_verbose,
  */
 char *libipv6calc_db_wrapper_DBIP2_wrapper_db_info_used(void) {
 	int type, i;
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 	char *info;
 
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_DBIP2, "Called");
@@ -493,7 +542,7 @@ char *libipv6calc_db_wrapper_DBIP2_wrapper_db_info_used(void) {
  * wrapper extension: DBIP2_dbfilename
  */
 static char *libipv6calc_db_wrapper_DBIP2_dbfilename(const unsigned int type) {
-	static char tempstring[NI_MAXHOST];
+	static char tempstring[IPV6CALC_STRING_MAX];
 	int  entry = -1, i;
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_DBIP2, "Called: %s type=%d", wrapper_dbip2_info, type);
@@ -650,9 +699,9 @@ END_libipv6calc_db_wrapper:
  * wrapper: DBIP2_database_info
  */
 char *libipv6calc_db_wrapper_DBIP2_database_info(const unsigned int type) {
-	static char resultstring[NI_MAXHOST];
-	char datastring[NI_MAXHOST];
-	char tempstring[NI_MAXHOST];
+	static char resultstring[IPV6CALC_STRING_MAX];
+	char datastring[IPV6CALC_STRING_MAX];
+	char tempstring[IPV6CALC_STRING_MAX];
 
 	MMDB_s mmdb;
 	int ret, i, entry = -1;
@@ -726,19 +775,6 @@ END_libipv6calc_db_wrapper:
 };
 
 
-/*
- * wrapper: DBIP2_get_country_short
- */
-char *libipv6calc_db_wrapper_DBIP2_get_country_short(DB *dbp, char *ip) {
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_DBIP2, "Called: %s ip=%s", wrapper_dbip2_info, ip);
-
-	// not implemented so far
-	if (dbp == NULL) { }; // make compiler happy (avoid unused "...")
-	//return(DBIP2_get_country_short(loc, ip));
-	return(NULL);
-};
-
-
 /*********************************************
  * Abstract functions
  * *******************************************/
