@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_GeoIP2.c
- * Version    : $Id: 9731235069a246ee79dcb8a34f04a6ac7b1fbf76 $
- * Copyright  : 2019-2019 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: bde02da0fbec8a8c3f8966aae04086d08aec5730 $
+ * Copyright  : 2019-2021 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  ipv6calc DB-IP.com database wrapper for MaxMindDB databases
@@ -20,21 +20,72 @@
 
 #include "libipv6calcdebug.h"
 #include "libipv6calc.h"
+#include "libipaddr.h"
 
 #include "libipv6calc_db_wrapper.h"
 
 
 #ifdef SUPPORT_GEOIP2
 
-#include <db.h>
-
 #include "libipv6calc_db_wrapper_GeoIP2.h"
 
-char geoip2_db_dir[NI_MAXHOST] = GEOIP2_DB;
+char geoip2_db_dir[PATH_MAX] = GEOIP2_DB;
 
 static const char* wrapper_geoip2_info = "GeoIP2";
 
 
+/* database files */
+static const db_file_desc2 libipv6calc_db_wrapper_GeoIP2_db_file_desc[] = {
+	// country (lite)
+	{ GeoIP2_DB_COUNTRY_LITE
+		, "GeoLite2-Country.mmdb"
+		, "IPv4/v6 CountryCode (FREE)"
+		, IPV6CALC_DB_IP_TO_CC | IPV6CALC_DB_IP_TO_GEONAMEID | IPV6CALC_DB_IP_TO_COUNTRY | IPV6CALC_DB_GEOIP
+		, IPV6CALC_DB_GEOIP2_INTERNAL_FREE
+	},
+
+	// city (lite)
+	{ GeoIP2_DB_CITY_LITE
+		, "GeoLite2-City.mmdb"
+		, "IPv4/v6 City (FREE)"
+		, IPV6CALC_DB_IP_TO_CITY | IPV6CALC_DB_IP_TO_REGION | IPV6CALC_DB_IP_TO_CC | IPV6CALC_DB_GEOIP | IPV6CALC_DB_IP_TO_GEONAMEID
+		, IPV6CALC_DB_GEOIP2_INTERNAL_FREE
+	},
+
+	// ASN (lite)
+	{ GeoIP2_DB_ASN
+		, "GeoLite2-ASN.mmdb"
+		, "IPv4/v6 ASN (FREE)"
+		, IPV6CALC_DB_IP_TO_AS | IPV6CALC_DB_GEOIP
+		, IPV6CALC_DB_GEOIP2_INTERNAL_FREE
+	},
+
+	// country
+	{ GeoIP2_DB_COUNTRY
+		, "Geo2-Country.mmdb"
+		, "IPv4/v6 CountryCode (COMM)"
+		, IPV6CALC_DB_IP_TO_CC | IPV6CALC_DB_IP_TO_GEONAMEID | IPV6CALC_DB_IP_TO_COUNTRY | IPV6CALC_DB_GEOIP
+		, IPV6CALC_DB_GEOIP2_INTERNAL_COMM
+	},
+
+	// city
+	{ GeoIP2_DB_CITY
+		, "Geo2-City.mmdb"
+		, "IPv4/v6 City (COMM)"
+		, IPV6CALC_DB_IP_TO_CITY | IPV6CALC_DB_IP_TO_REGION | IPV6CALC_DB_IP_TO_CC | IPV6CALC_DB_GEOIP | IPV6CALC_DB_IP_TO_GEONAMEID
+		, IPV6CALC_DB_GEOIP2_INTERNAL_COMM
+	},
+
+	// ISP
+	{ GeoIP2_DB_ISP
+		, "Geo2-ISP.mmdb"
+		, "IPv4/v6 ISP (COMM)"
+		, IPV6CALC_DB_IP_TO_AS | IPV6CALC_DB_GEOIP
+		, IPV6CALC_DB_GEOIP2_INTERNAL_COMM
+	},
+};
+
+
 // DB used for resolution after automatic election, which is currently done by checking for DB files and the sequence in the header file
 static int geoip2_db_country_v4 = 0;
 static int geoip2_db_country_v6 = 0;
@@ -87,7 +138,7 @@ static uint32_t geoip2_db_usage_map[GeoIP2_DB_MAX_BLOCKS_32];
 							exit(1); \
 						};
 
-char geoip2_db_usage_string[NI_MAXHOST] = "";
+char geoip2_db_usage_string[IPV6CALC_STRING_MAX] = "";
 
 // local cache
 static MMDB_s mmdb_cache[GeoIP2_DB_MAX+1];
@@ -461,7 +512,7 @@ void libipv6calc_db_wrapper_GeoIP2_wrapper_print_db_info(const int level_verbose
  */
 char *libipv6calc_db_wrapper_GeoIP2_wrapper_db_info_used(void) {
 	int type, i;
-	char tempstring[NI_MAXHOST];
+	char tempstring[IPV6CALC_STRING_MAX];
 	char *info;
 
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "Called");
@@ -510,7 +561,7 @@ char *libipv6calc_db_wrapper_GeoIP2_wrapper_db_info_used(void) {
  * wrapper extension: GeoIP2_dbfilename
  */
 static char *libipv6calc_db_wrapper_GeoIP2_dbfilename(const unsigned int type) {
-	static char tempstring[NI_MAXHOST];
+	static char tempstring[IPV6CALC_STRING_MAX];
 	int  entry = -1, i;
 
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "Called: %s type=%d", wrapper_geoip2_info, type);
@@ -667,9 +718,9 @@ END_libipv6calc_db_wrapper:
  * wrapper: GeoIP2_database_info
  */
 char *libipv6calc_db_wrapper_GeoIP2_database_info(const unsigned int type) {
-	static char resultstring[NI_MAXHOST];
-	char datastring[NI_MAXHOST];
-	char tempstring[NI_MAXHOST];
+	static char resultstring[IPV6CALC_STRING_MAX];
+	char datastring[IPV6CALC_STRING_MAX];
+	char tempstring[IPV6CALC_STRING_MAX];
 
 	MMDB_s mmdb;
 	int ret, i, entry = -1;
@@ -743,19 +794,6 @@ END_libipv6calc_db_wrapper:
 };
 
 
-/*
- * wrapper: GeoIP2_get_country_short
- */
-char *libipv6calc_db_wrapper_GeoIP2_get_country_short(DB *dbp, char *ip) {
-	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_GeoIP2, "Called: %s ip=%s", wrapper_geoip2_info, ip);
-
-	// not implemented so far
-	if (dbp == NULL) { }; // make compiler happy (avoid unused "...")
-	//return(GeoIP2_get_country_short(loc, ip));
-	return(NULL);
-};
-
-
 /*********************************************
  * Abstract functions
  * *******************************************/
