@@ -1,12 +1,12 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calc/ipv6calc.c
- * Version    : $Id: 326939d66c69589c5f2d78f3bcaced782975dbad $
- * Copyright  : 2001-2019 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 9b0fdb0e586710db48433f73ca0f7763d00fb524 $
+ * Copyright  : 2001-2021 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Central program (main)
- *  This program print out different formats of an given IP(v4/v6)/MAC address
+ *  This program print out different formats of a given IP(v4/v6)/MAC address
  */
 
 #include <stdio.h>
@@ -77,7 +77,7 @@ s_ipv6calc_anon_set ipv6calc_anon_set;
 
 /* features */
 int feature_zeroize = 1; // always supported
-int feature_anon    = 1; // always supported
+int feature_anon    = 0; // will be checked later
 int feature_kp      = 0; // will be checked later
 int feature_kg      = 0; // will be checked later
 
@@ -95,11 +95,11 @@ int main(int argc, char *argv[]) {
 	IPV6CALC_DB_LIB_VERSION_CHECK_EXIT(IPV6CALC_PACKAGE_VERSION_NUMERIC, IPV6CALC_PACKAGE_VERSION_STRING)
 #endif // SHARED_LIBRARY
 
-	char resultstring[NI_MAXHOST] = "";
-	char resultstring2[NI_MAXHOST] = "";
-	char resultstring3[NI_MAXHOST] = "";
+	char resultstring[IPV6CALC_STRING_MAX] = "";
+	char resultstring2[IPV6CALC_STRING_MAX] = "";
+	char resultstring3[IPV6CALC_STRING_MAX] = "";
+	char name_ipset[IPV6CALC_STRING_MAX] = "";
 	int retval = 1, i, j, lop, result;
-	extern int optopt;
 	uint32_t command = 0;
 	int bit_start = 0, bit_end = 0, force_prefix = 0;
 	char *input1 = NULL, *input2 = NULL;
@@ -122,6 +122,7 @@ int main(int argc, char *argv[]) {
 	ipv6calc_ipv4addr ipv4addr, ipv4addr2;
 	ipv6calc_macaddr  macaddr;
 	ipv6calc_eui64addr  eui64addr;
+	ipv6calc_ipaddr ipaddr;
 
 	/* arrays of structures and chars for "test" action */
 	#define ipv6calc_arrays (IPV6CALC_TEST_LIST_MAX + 1)
@@ -143,6 +144,9 @@ int main(int argc, char *argv[]) {
 	s_iid_statistics iid_statistics;
 	int iid_random_result;
 
+	/* database source */
+	int db_source;
+
 	/* clear address structures */
 	ipv6addr_clearall(&ipv6addr);
 	ipv6addr_clearall(&ipv6addr2);
@@ -170,7 +174,7 @@ int main(int argc, char *argv[]) {
 
 	/* options */
 	struct option longopts[IPV6CALC_MAXLONGOPTIONS];
-	char   shortopts[NI_MAXHOST] = "";
+	char   shortopts[IPV6CALC_STRING_MAX] = "";
 	int    longopts_maxentries = 0;
 
 	/* initialize debug value from environment for bootstrap debugging */
@@ -261,30 +265,6 @@ int main(int argc, char *argv[]) {
 				DEBUGPRINT_NA(DEBUG_ipv6calc_general, "help option detected");
 				break;
 				
-			case 'L':
-				fprintf(stderr, "Option is obsolete: -L\n");
-				break;
-
-			case DB_ip2location_ipv4_default:
-				fprintf(stderr, "Option is obsolete: --db-ip2location-ipv4-default\n");
-				break;
-
-			case DB_ip2location_ipv6_default:
-				fprintf(stderr, "Option is obsolete: --db-ip2location-ipv6-default\n");
-				break;
-
-			case 'G':
-				fprintf(stderr, "Option is obsolete: -G\n");
-				break;
-
-			case DB_geoip_ipv4_default:
-				fprintf(stderr, "Option is obsolete: --db-geoip-ipv4-default\n");
-				break;
-
-			case DB_geoip_ipv6_default:
-				fprintf(stderr, "Option is obsolete: --db-geoip-ipv6-default\n");
-				break;
-
 			case CMD_printexamples:
 				command = CMD_printexamples;
 				break;
@@ -527,6 +507,10 @@ int main(int argc, char *argv[]) {
 			case FORMATOPTION_NUM_printuppercase + FORMATOPTION_NUM_HEAD:
 				formatoptions |= FORMATOPTION_printuppercase;
 				break;
+
+			case FORMATOPTION_NUM_no_prefixlength + FORMATOPTION_NUM_HEAD:
+				formatoptions |= FORMATOPTION_no_prefixlength;
+				break;
 				
 			case FORMATOPTION_NUM_forceprefix + FORMATOPTION_NUM_HEAD:
 				DEBUGPRINT_NA(DEBUG_ipv6calc_general, "format option 'forceprefix' selected");
@@ -632,6 +616,20 @@ int main(int argc, char *argv[]) {
 	       			formatoptions |= FORMATOPTION_printfulluncompressed;
 				break;
 
+			case FORMATOPTION_NUM_print_octal + FORMATOPTION_NUM_HEAD:
+				formatoptions |= FORMATOPTION_print_octal;
+				break;
+
+			case FORMATOPTION_NUM_print_ipset + FORMATOPTION_NUM_HEAD:
+				if (strlen(optarg) >= sizeof(name_ipset)) {
+					fprintf(stderr, " Argument of option 'print-ipset' is too long: %s\n", optarg);
+					exit(EXIT_FAILURE);
+				};
+				snprintf(name_ipset, sizeof(name_ipset), "%s", optarg);
+				formatoptions |= FORMATOPTION_print_ipset;
+				break;
+
+
 			/* new options */
 			case 'I':	
 			case CMD_inputtype:
@@ -742,6 +740,12 @@ int main(int argc, char *argv[]) {
 		feature_kg = 1;
 	};
 
+	/* check for standard anonymization support */
+	if ((libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_REGISTRY) == 1) \
+	    && (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV6_TO_REGISTRY) == 1)) {
+		feature_anon = 1;
+	};
+
 	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Debug value:%08lx command:%08lx inputtype:%08lx outputtype:%08lx action:%08lx formatoptions:%08lx", (unsigned long) ipv6calc_debug, (unsigned long) command, (unsigned long) inputtype, (unsigned long) outputtype, (unsigned long) action, (unsigned long) formatoptions); // ipv6calc_debug usage ok
 
 	/* do work depending on selection */
@@ -782,7 +786,7 @@ int main(int argc, char *argv[]) {
 				printhelp_inputtypes(formatoptions);
 			} else {
 				DEBUGPRINT_NA(DEBUG_ipv6calc_general, "printhelp_output_dispatcher");
-				printhelp_output_dispatcher(outputtype);
+				printhelp_output_dispatcher(outputtype, inputtype);
 			};
 			exit(EXIT_FAILURE);
 		} else if (action == ACTION_auto) {
@@ -796,7 +800,7 @@ int main(int argc, char *argv[]) {
 		};
 
 	} else if (command == CMD_printexamples) {
-		printhelp_output_dispatcher(outputtype);
+		printhelp_output_dispatcher(outputtype, inputtype);
 		exit(EXIT_FAILURE);
 	} else if (command == CMD_showinfotypes) {
 		showinfo_availabletypes();
@@ -828,10 +832,33 @@ int main(int argc, char *argv[]) {
 		};
 		if (result == 0) {
 			fprintf(stderr, "ipv6calc action 'test' misses prefix or begin/end for testing\n");
-			exit(EXIT_FAILURE);
+			retval = 1;
+			goto RESULT_none;
 		};
 	};
 
+	if (action == ACTION_db_dump) {
+		if ((filter_master.filter_ipv4addr.active == 0) && (filter_master.filter_ipv6addr.active == 0)) {
+			fprintf(stderr, "ipv6calc action 'dbdump' require a valid IPv4 or IPv6 filter (see option -E ...)\n");
+			retval = 1;
+			goto RESULT_none;
+		};
+
+		// TODO SOURCE SELECTION in case more databases support dump format
+		db_source = IPV6CALC_DB_SOURCE_EXTERNAL;
+
+		if ((filter_master.filter_ipv4addr.active == 0) && (filter_master.filter_ipv6addr.active != 0)) {
+			retval = libipv6calc_db_dump(db_source, IPV6CALC_PROTO_IPV6, &filter_master, outputtype, formatoptions, name_ipset);
+		} else if ((filter_master.filter_ipv4addr.active != 0) && (filter_master.filter_ipv6addr.active == 0)) {
+			retval = libipv6calc_db_dump(db_source, IPV6CALC_PROTO_IPV4, &filter_master, outputtype, formatoptions, name_ipset);
+		} else {
+			fprintf(stderr, "ipv6calc action 'dbdump' is not supporting combined IPv4 and IPv6 filter\n");
+			retval = 1;
+			goto RESULT_none;
+		};
+		goto RESULT_none;
+	};
+
 	if (argc > 0) {
 		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Got input: %s", argv[0]);
 	} else {
@@ -854,7 +881,7 @@ int main(int argc, char *argv[]) {
 		};
 		for (i = 0; i < argc; i++) {
 			if ( argv[i] != NULL ) {
-				if ( strlen(argv[i]) >= NI_MAXHOST ) {
+				if ( strlen(argv[i]) >= IPV6CALC_STRING_MAX ) {
 					/* that's not good for size limited buffers...*/
 					fprintf(stderr, "Argument %d is too long\n", i + 1);
 					exit(EXIT_FAILURE);
@@ -882,7 +909,7 @@ PIPE_input:
 		
 		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Line: %d", linecounter);
 
-		if (strlen(linebuffer) >= NI_MAXHOST) {
+		if (strlen(linebuffer) >= IPV6CALC_STRING_MAX) {
 			fprintf(stderr, "Line too long: %d\n", linecounter);
 			exit(EXIT_FAILURE);
 		};
@@ -969,7 +996,7 @@ PIPE_input:
 		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "call input type autodetection resulted in 0x%08x", inputtype);
 
 		if ( inputtype != FORMAT_undefined ) {
-			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatstrings); i++) {
+			for (i = 0; i < ipv6calc_formatstrings_entries; i++) {
 				if (inputtype == ipv6calc_formatstrings[i].number) {
 					if ((formatoptions & FORMATOPTION_quiet) == 0) {
 						fprintf(stderr, "found type: %s\n", ipv6calc_formatstrings[i].token);
@@ -986,7 +1013,7 @@ PIPE_input:
 
 	/* auto set of output type*/
 	if (inputtype == FORMAT_revnibbles_int || inputtype == FORMAT_revnibbles_arpa || inputtype == FORMAT_ipv6literal) {
-		if ( outputtype == FORMAT_undefined ) {
+		if ((outputtype == FORMAT_undefined) && (command != CMD_showinfo)) {
 			outputtype = FORMAT_ipv6addr;
 		};
 	};
@@ -1016,7 +1043,7 @@ PIPE_input:
 			if ((formatoptions & FORMATOPTION_quiet) == 0) {
 				fprintf(stderr, "No action type specified, try autodetection...");
 			};
-			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_actionstrings); i++) {
+			for (i = 0; i < ipv6calc_actionstrings_entries; i++) {
 				if (action == ipv6calc_actionstrings[i].number) {
 					if ((formatoptions & FORMATOPTION_quiet) == 0) {
 						fprintf(stderr, "found type: %s\n", ipv6calc_actionstrings[i].token);
@@ -1028,9 +1055,9 @@ PIPE_input:
 	};
 
 	/* check formatoptions for validity */
-	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "check format option of output type: 0x%08lx", (unsigned long) outputtype);
+	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "check format option of output type: 0x%08lx (0x%08x)", (unsigned long) outputtype, formatoptions);
 		
-	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_outputformatoptionmap); i++) {
+	for (i = 0; i < ipv6calc_outputformatoptionmap_entries; i++) {
 		if (outputtype != ipv6calc_outputformatoptionmap[i][0]) {
 			continue;
 		};
@@ -1044,10 +1071,10 @@ PIPE_input:
 			/* workaround */
 			continue;
 		};
-		fprintf(stderr, " Unsupported format option(s):\n");
+		fprintf(stderr, "Unsupported format option(s):\n");
 
 		/* run through format options */
-		for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatoptionstrings); j++) {
+		for (j = 0; j < ipv6calc_formatoptionstrings_entries; j++) {
 			if ( (ipv6calc_formatoptionstrings[j].number & FORMATOPTION_quiet) != 0 ) {
 				/* skip format option "quiet" on check */
 				continue;
@@ -1232,6 +1259,19 @@ PIPE_input:
 			ipv4addr.flag_prefixuse = 1;
 			ipv4addr.prefixlength = force_prefix;
 		};
+
+		if ((formatoptions & (FORMATOPTION_maskprefix | FORMATOPTION_masksuffix)) != 0) {
+			if (ipv4addr.flag_prefixuse == 1) {
+				if ((formatoptions & FORMATOPTION_maskprefix) != 0) {
+					ipv4addrstruct_maskprefix(&ipv4addr);
+				} else if ((formatoptions & FORMATOPTION_masksuffix) != 0) {
+					ipv4addrstruct_masksuffix(&ipv4addr);
+				};
+			} else {
+				fprintf(stderr, " Error: mask option used without specifying a prefix length\n");
+				exit(EXIT_FAILURE);
+			};
+		};
 	};
 
 	if (ipv6addr.flag_valid == 1) {
@@ -1383,7 +1423,7 @@ PIPE_input:
 		};
 
 		if ( outputtype != FORMAT_undefined ) {
-			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatstrings); i++) {
+			for (i = 0; i < ipv6calc_formatstrings_entries; i++) {
 				if (outputtype == ipv6calc_formatstrings[i].number) {
 					if ((formatoptions & FORMATOPTION_quiet) == 0) {
 						fprintf(stderr, "found type: %s\n", ipv6calc_formatstrings[i].token);
@@ -2003,6 +2043,48 @@ PIPE_input:
 		goto RESULT_print;
 	};
 
+	/* catch error cases in advance */
+	switch (outputtype) {
+		case FORMAT_base85:
+		case FORMAT_bitstring:
+		case FORMAT_ifinet6:
+		case FORMAT_ipv6addr:
+		case FORMAT_ipv6literal:
+		case FORMAT_revnibbles_int:
+		case FORMAT_revnibbles_arpa:
+		case FORMAT_iid_token:
+			if (ipv6addr.flag_valid != 1) {
+				fprintf(stderr, "No valid IPv6 address given%s!\n",
+					(inputtype_given > 0) ? " (no action autoselected from specified input type)": ""
+				);
+				exit(EXIT_FAILURE);
+			};
+			break;
+
+		case FORMAT_ipv4addr:
+		case FORMAT_ipv4hex:
+		case FORMAT_revipv4:
+		case FORMAT_ipv6to4:
+			if (ipv4addr.flag_valid != 1) {
+				fprintf(stderr, "No valid IPv4 address given%s!\n",
+					(inputtype_given > 0) ? " (no action autoselected from specified input type)": ""
+				);
+				exit(EXIT_FAILURE);
+			};
+			break;
+
+		case FORMAT_mac:
+			if (macaddr.flag_valid != 1) {
+				fprintf(stderr, "No valid MAC address given%s!\n",
+					(inputtype_given > 0) ? " (no action autoselected from specified input type)": ""
+				);
+				exit(EXIT_FAILURE);
+			};
+			break;
+
+	};
+
+	/* process output */
 	switch (outputtype) {
 		case -1:
 			/* old implementation */
@@ -2010,13 +2092,11 @@ PIPE_input:
 
 		case FORMAT_base85:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_base85");
-			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
 			retval = ipv6addrstruct_to_base85(&ipv6addr, resultstring, sizeof(resultstring));
 			break;
 				
 		case FORMAT_bitstring:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_bitstring");
-			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Call 'librfc2874_addr_to_bitstring'");
 			retval = librfc2874_addr_to_bitstring(&ipv6addr, resultstring, sizeof(resultstring), formatoptions);
 			break;
@@ -2041,46 +2121,34 @@ PIPE_input:
 
 		case FORMAT_ipv4hex:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_ipv4hex");
-			if (ipv4addr.flag_valid == 1) {
-				retval = libipv4addr_to_hex(&ipv4addr, resultstring, sizeof(resultstring), formatoptions);
-			};
+			retval = libipv4addr_to_hex(&ipv4addr, resultstring, sizeof(resultstring), formatoptions);
 			break;
 				
 		case FORMAT_revnibbles_int:
 		case FORMAT_revnibbles_arpa:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_revnibbles_int/arpa");
-			if (ipv6addr.flag_valid == 1) {
-				switch (outputtype) {
-					case FORMAT_revnibbles_int:
-						retval = librfc1886_addr_to_nibblestring(&ipv6addr, resultstring, sizeof(resultstring), formatoptions, "ip6.int.");
-						break;
-					case FORMAT_revnibbles_arpa:
-						retval = librfc1886_addr_to_nibblestring(&ipv6addr, resultstring, sizeof(resultstring), formatoptions, "ip6.arpa.");
-						break;
-				};
-			} else {
-			       fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE);
+			switch (outputtype) {
+				case FORMAT_revnibbles_int:
+					retval = librfc1886_addr_to_nibblestring(&ipv6addr, resultstring, sizeof(resultstring), formatoptions, "ip6.int.");
+					break;
+				case FORMAT_revnibbles_arpa:
+					retval = librfc1886_addr_to_nibblestring(&ipv6addr, resultstring, sizeof(resultstring), formatoptions, "ip6.arpa.");
+					break;
 			};
 			break;
 				
 		case FORMAT_revipv4:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_revipv4");
-			if (ipv4addr.flag_valid == 1) {
-				retval = libipv4addr_to_reversestring(&ipv4addr, resultstring, sizeof(resultstring), formatoptions);
-			} else {
-			       fprintf(stderr, "No valid IPv4 address given!\n"); exit(EXIT_FAILURE);
-		       	};
+			retval = libipv4addr_to_reversestring(&ipv4addr, resultstring, sizeof(resultstring), formatoptions);
 			break;
 			
 		case FORMAT_ifinet6:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_ifinet6");
-			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
 			retval = libifinet6_ipv6addrstruct_to_ifinet6(&ipv6addr, resultstring, sizeof(resultstring));
 			break;
 
 		case FORMAT_ipv6addr:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_ipv6addr");
-			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
 			if ((formatoptions & (FORMATOPTION_printuncompressed | FORMATOPTION_printfulluncompressed | FORMATOPTION_printprefix | FORMATOPTION_printsuffix)) != 0) {
 				retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, sizeof(resultstring), formatoptions);
 			} else {
@@ -2104,7 +2172,6 @@ PIPE_input:
 
 		case FORMAT_ipv6literal:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_ipv6literal");
-			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
 			if ((formatoptions & (FORMATOPTION_printuncompressed | FORMATOPTION_printfulluncompressed)) != 0) {
 				retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, sizeof(resultstring), formatoptions | FORMATOPTION_literal);
 			} else {
@@ -2115,10 +2182,16 @@ PIPE_input:
 			
 		case FORMAT_ipv4addr:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_ipv4addr");
-			if (ipv4addr.flag_valid != 1) { fprintf(stderr, "No valid IPv4 address given!\n"); exit(EXIT_FAILURE); };
 			retval = libipv4addr_ipv4addrstruct_to_string(&ipv4addr, resultstring, sizeof(resultstring), formatoptions);
 			break;
 
+		case FORMAT_ipv6to4:
+			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_ipv6to4");
+			retval = librfc3056_ipv4addr_to_ipv6to4addr(&ipv6addr, &ipv4addr);
+			CONVERT_IPV6ADDRP_IPADDR(&ipv6addr, ipaddr);
+			retval = libipaddr_ipaddrstruct_to_string(&ipaddr, resultstring, sizeof(resultstring), formatoptions);
+			break;
+
 		case FORMAT_eui64:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_eui64");
 
@@ -2136,13 +2209,12 @@ PIPE_input:
 			
 		case FORMAT_mac:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_mac");
-			if (macaddr.flag_valid != 1) { fprintf(stderr, "No valid MAC address given!\n"); exit(EXIT_FAILURE); };
 			retval = macaddrstruct_to_string(&macaddr, resultstring, sizeof(resultstring), formatoptions);
 			break;
 			
 		case FORMAT_iid_token:
 			DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of output handling for FORMAT_iid_token");
-			if (ipv6addr.flag_valid != 1 || ipv6addr2.flag_valid != 1) { fprintf(stderr, "No valid IPv6 addresses given!\n"); exit(EXIT_FAILURE); };
+			if (ipv6addr2.flag_valid != 1) { fprintf(stderr, "No valid second IPv6 address given!\n"); exit(EXIT_FAILURE); };
 			/* get interface identifier */
 			retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring2, sizeof(resultstring2), formatoptions | FORMATOPTION_printsuffix);
 			if (retval != 0) { break; };
@@ -2179,7 +2251,8 @@ RESULT_print:
 		goto PIPE_input;
 	};
 
-	libipv6calc_db_wrapper_cleanup();
+RESULT_none:
+	libipv6calc_cleanup();
 
 	exit(retval);
 };
