@@ -1,17 +1,17 @@
-#!/bin/sh
+#!/usr/bin/env bash
 #
 # Project    : ipv6calc
 # File       : test_ipv6calc.sh
-# Version    : $Id: 0591b1b652b78be3e17845c8ae7fe7dafd709503 $
-# Copyright  : 2001-2015 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: be71eebec983c4f9710e15a0c96f13846661beb8 $
+# Copyright  : 2001-2021 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc conversions
 
-verbose=0
+verbose=false
 while getopts "Vh\?" opt; do
 	case $opt in
 	    V)
-		verbose=1
+		verbose=true
 		;;
 	    *)
 		echo "$0 [-V]"
@@ -55,6 +55,13 @@ cat <<END | grep -v '^#'
 ## to uncompressed
 --addr_to_compressed 3ffe:ffff:0100:f101:0000:0000:0000:0001		=3ffe:ffff:100:f101::1
 --in ipv6 --out ipv6 --printcompressed 3ffe:ffff:0100:f101:0000:0000:0000:0001 =3ffe:ffff:100:f101::1
+# :0: is not allowed to be compressed according to RFC5952 (https://github.com/pbiering/ipv6calc/issues/28)
+--in ipv6 --out ipv6 --printcompressed 2001:db8:0:1:1:1:1:1             =2001:db8:0:1:1:1:1:1 
+--in ipv6 --out ipv6 --printcompressed 2001:db8:0:0:1:1:1:1             =2001:db8::1:1:1:1 
+--in ipv6 --out ipv6 --printcompressed 0:db8:0:1:1:1:1:1                =0:db8:0:1:1:1:1:1 
+--in ipv6 --out ipv6 --printcompressed 0:0:db8:1:1:1:1:1                =::db8:1:1:1:1:1 
+--in ipv6 --out ipv6 --printcompressed 2001:db8:0:1:1:1:1:0             =2001:db8:0:1:1:1:1:0 
+--in ipv6 --out ipv6 --printcompressed 2001:db8:0:1:1:1:0:0             =2001:db8:0:1:1:1:: 
 -I ipv6 -O ipv6 -C 3ffe:ffff:0100:f101:0000:0000:0000:0001 		=3ffe:ffff:100:f101::1
 --addr_to_compressed 3ffe:ffff:0100:f101:0000:0000:0000:0001/64		=3ffe:ffff:100:f101::1/64
 --addr_to_compressed 0:0:2:2:3:4:0:0					=::2:2:3:4:0:0
@@ -72,7 +79,7 @@ cat <<END | grep -v '^#'
 --addr_to_compressed 0:0:0:0:0:0:13.1.68.3				=::13.1.68.3
 --addr_to_compressed 0:0:0:0:0:ffff:129.144.52.38			=::ffff:129.144.52.38
 --addr_to_compressed --uppercase 0:0:0:0:0:ffff:129.144.52.38		=::FFFF:129.144.52.38
---addr_to_compressed fd00:1234:5678:0:210:a4ff:fe01:2345		=fd00:1234:5678::210:a4ff:fe01:2345
+--addr_to_compressed fd00:1234:5678:0:210:a4ff:fe01:2345		=fd00:1234:5678:0:210:a4ff:fe01:2345
 --in ipv6 --out ipv6 --printcompressed --uppercase 0:0:0:0:0:ffff:129.144.52.38		=::FFFF:129.144.52.38
 ## uncompressed
 --addr_to_uncompressed 3ffe:ffff:100:f101::1				=3ffe:ffff:100:f101:0:0:0:1
@@ -91,6 +98,28 @@ cat <<END | grep -v '^#'
 --addr_to_uncompressed --maskprefix 3ffe:ffff:100:f101::1/64		=3ffe:ffff:100:f101:0:0:0:0/64
 --addr_to_uncompressed --masksuffix 3ffe:ffff:100:f101:c000::1/64	=0:0:0:0:c000:0:0:1/64
 --addr_to_uncompressed --uppercase ::ffff:13.1.68.3			=0:0:0:0:0:FFFF:13.1.68.3
+--out ipv4addr --no-prefixlength 1.2.3.4				=1.2.3.4
+--out ipv4addr --no-prefixlength 1.2.3.4/24				=1.2.3.4
+--out ipv4addr --no-prefixlength 1.2.3/24				=1.2.3.0
+--out ipv4addr --no-prefixlength 1.2/24					=1.2.0.0
+--out ipv4addr --no-prefixlength 1/24					=1.0.0.0
+--out ipv4addr 1.2.3.4/0						=1.2.3.4/0
+--out ipv4addr 0/0							=0.0.0.0/0
+--out ipv4addr --printcompressed 0/0					=0/0
+--out ipv4addr --printcompressed 1.2.3.4/24				=1.2.3.4/24
+--out ipv4addr --printcompressed 1.2.3.0/24				=1.2.3/24
+--out ipv4addr --printcompressed 1.2.3/24				=1.2.3/24
+--out ipv4addr --printcompressed 1.2.0.0/24				=1.2/24
+--out ipv4addr --printcompressed 1.2/24					=1.2/24
+--out ipv4addr --printcompressed 1.0.0.0/24				=1/24
+--out ipv4addr --printcompressed 1/24					=1/24
+--out ipv4addr --maskprefix 1.2.3.4/24					=1.2.3.0/24
+--out ipv4addr --maskprefix 1.2.3./24					=1.2.3.0/24
+--out ipv4addr --maskprefix 1.2./24					=1.2.0.0/24
+--out ipv4addr --maskprefix 1./24					=1.0.0.0/24
+--out ipv4addr --masksuffix 1.2.3.4/24					=0.0.0.4/24
+--out ipv4addr --maskprefix 1.2.3.4/22					=1.2.0.0/22
+--out ipv4addr --masksuffix 1.2.3.4/22 					=0.0.3.4/22
 # selecting suffix/prefix
 --addr_to_uncompressed --printsuffix ::ffff:1.2.3.4/64			=0:ffff:1.2.3.4
 --in ipv6 --out ipv6 --printsuffix --printuncompressed ::ffff:1.2.3.4/64			=0:ffff:1.2.3.4
@@ -99,6 +128,16 @@ cat <<END | grep -v '^#'
 --addr_to_uncompressed --printprefix 3ffe:ffff:100:f101::1/64		=3ffe:ffff:100:f101
 --addr_to_uncompressed --printprefix 3ffe:ffff:100:f101::1/65		=3ffe:ffff:100:f101:0
 --in ipv6 --out ipv6 --printprefix --printuncompressed 3ffe:ffff:100:f101::1/65		=3ffe:ffff:100:f101:0
+## octal IPv4 (with separator)
+--in ipv4 --out ipv4 --print-octal 192.0.2.1				=0300.0000.0002.0001
+--in ipv4 --out ipv4 --print-octal 192.0.2.1/24				=0300.0000.0002.0001/24
+--in ipv4 --out ipv4 0300.0000.0002.0001				=192.0.2.1
+--in ipv4 --out ipv4 0300.0000.0002.0001/24				=192.0.2.1/24
+## octal IP
+--in ipv4 --out octal 192.0.2.1						=\\\\0300\\\\00\\\\02\\\\01
+--in ipv4 --out octal --printfulluncompressed 192.0.2.1			=\\\\0300\\\\0000\\\\0002\\\\0001
+--in ipv6 --out octal 3ffe:ffff::1					=\\\\077\\\\0376\\\\0377\\\\0377\\\\00\\\\00\\\\00\\\\00\\\\00\\\\00\\\\00\\\\00\\\\00\\\\00\\\\00\\\\01
+--in ipv6 --out octal --printfulluncompressed 3ffe:ffff::1		=\\\\0077\\\\0376\\\\0377\\\\0377\\\\0000\\\\0000\\\\0000\\\\0000\\\\0000\\\\0000\\\\0000\\\\0000\\\\0000\\\\0000\\\\0000\\\\0001
 ## full uncompressed
 --addr_to_fulluncompressed 3ffe:ffff:100:f101::1			=3ffe:ffff:0100:f101:0000:0000:0000:0001
 --in ipv6 --out ipv6 --printfulluncompressed 3ffe:ffff:100:f101::1 =3ffe:ffff:0100:f101:0000:0000:0000:0001
@@ -144,15 +183,24 @@ NOPIPETEST--out eui64 00:0:F:6:4:5					=200:fff:fe06:405
 --ipv4_to_6to4addr 11.12.13.14						=2002:b0c:d0e::
 --in ipv4 --out ipv6 --action conv6to4 11.12.13.14			=2002:b0c:d0e::
 --action conv6to4 192.0.2.1						=2002:c000:201::
+--no-prefixlength --action conv6to4 192.0.2.1/24 			=2002:c000:200::
+--action conv6to4 192.0.2.1/24						=2002:c000:200::/40
 ## IPv6 -> IPv4 (6to4)
 --in ipv6 --out ipv4 --action conv6to4 2002:102:304::1			=1.2.3.4
---action conv6to4 2002:c000:201::					=192.0.2.1
+--action conv6to4 2002:c000:201:: 					=192.0.2.1
+--no-prefixlength --action conv6to4 2002:c000:201::/40			=192.0.2.0
+--action conv6to4 2002:c000:201::/40					=192.0.2.0/24
+## IPv4 -> IPv6 (6to4) with output format option
+-I ipv4 -O ipv6to4 1.2.3.4/24						=2002:102:300::/40
+-I ipv4 -O ipv6to4 1.2.3.4						=2002:102:304::
 ## IPv4 -> IPv6 (NAT64)
 --action convnat64 192.0.2.1						=64:ff9b::c000:201
 ## IPv6 -> IPv4 (NAT64)
 --action convnat64 64:ff9b::c000:201					=192.0.2.1
 ## Prefix + MAC -> IPv6
 --in prefix+mac fec0:0:0:1:: 01:23:45:67:89:01				=fec0::1:323:45ff:fe67:8901
+NOPIPETEST--in prefix+mac 1:2:3:4::/56 11:22:33:44:55:aa --action prefixmac2ipv6 --out ipv6addr  --force-prefix 64	=1:2:3:4:1322:33ff:fe44:55aa/64
+NOPIPETEST--in prefix+mac 1:2:3:4::/56 11:22:33:44:55:aa --action prefixmac2ipv6 --out ipv6addr --no-prefixlength	=1:2:3:4:1322:33ff:fe44:55aa
 ## IPv4 -> reverse
 --in ipv4addr --out revipv4 1.2.3.4					=4.3.2.1.in-addr.arpa.
 ## Information
@@ -163,12 +211,12 @@ NOPIPETEST--out eui64 00:0:F:6:4:5					=200:fff:fe06:405
 --action anonymize fe80:0000:0000:0000:0000:5e01:2345:6789		=fe80::a909:5214:e012:3451
 --action anonymize fe80:0000:0000:0000:0200:5e01:2345:6789		=fe80::a909:5214:f012:345f
 --action anonymize fe80:0000:0000:0000:0000:5eff:fe01:2345		=fe80::a909:5214:c010:1
---action anonymize 2001:0db8:0000:0000:81c0:0f3f:c807:1455		=2001:db8::9:a929:4941:0:c
+--action anonymize 2001:0db8:0000:0000:81c0:0f3f:c807:1455		=2001:db8:0:9:a929:4941:0:c
 --action anonymize 3ffe:831f:ce49:7601:8000:efff:af4a:86BF		=3ffe:831f:ce49:7601:8000:ffff:af4a:86ff
 --action anonymize --mask-ipv4 16 3ffe:831f:ce49:7601:8000:efff:af4a:86BF	=3ffe:831f:ce49:7601:8000:ffff:af4a:ffff
 --action anonymize 192.0.2.1						=192.0.2.0
 --action anonymize --mask-ipv4 16 192.0.2.1				=192.0.0.0
---action anonymize 2001:1a:392e:a450:2cd3:75e1:6098:8104		=2001:19:a909:a909:a999:4843::e
+--action anonymize 2001:1a:392e:a450:2cd3:75e1:6098:8104		=2001:19:a909:a909:a999:4843:0:e
 --action anonymize 01:23:45:67:89:ab					=01:23:45:00:00:00
 --action anonymize --mask-mac 48 01:23:45:67:89:ab			=01:23:45:67:89:ab
 --action anonymize --mask-mac 47 01:23:45:67:89:ab			=01:23:45:67:89:aa
@@ -179,7 +227,7 @@ NOPIPETEST--out eui64 00:0:F:6:4:5					=200:fff:fe06:405
 --action anonymize --mask-mac 7  ff:23:45:67:89:a8			=fe:00:00:00:00:00
 --action anonymize --mask-mac 1  ff:23:45:67:89:a8			=82:00:00:00:00:00
 -A anonymize --anonymize-preset zeroize-paranoid   2001:db8:2280:6901:224:21ff:fe01:2345  =2001:db8:2200::
--A anonymize --anonymize-preset zeroize-careful    2001:db8:2280:6901:224:21ff:fe01:2345  =2001:db8:2280::224:21ff:fe00:0
+-A anonymize --anonymize-preset zeroize-careful    2001:db8:2280:6901:224:21ff:fe01:2345  =2001:db8:2280:0:224:21ff:fe00:0
 -A anonymize --anonymize-preset zeroize-standard   2001:db8:2280:6901:224:21ff:fe01:2345  =2001:db8:2280:6900:224:21ff:fe00:0
 -A anonymize --anonymize-preset anonymize-paranoid 2001:db8:2280:6901:224:21ff:fe01:2345  =2001:db8:2209:a909:a969:4291:4022:4213
 -A anonymize --anonymize-preset anonymize-careful  2001:db8:2280:6901:224:21ff:fe01:2345  =2001:db8:2280:a909:a949:4291:4022:4219
@@ -187,7 +235,7 @@ NOPIPETEST--out eui64 00:0:F:6:4:5					=200:fff:fe06:405
 # RFC 5952 4.2.1
 --in ipv6addr --out ipv6addr 2001:db8:0:0:0:0:2:1			=2001:db8::2:1
 # RFC 5952 4.2.2
---in ipv6addr --out ipv6addr 2001:db8:0:1:1:1:1:1			=2001:db8::1:1:1:1:1
+--in ipv6addr --out ipv6addr 2001:db8:0:1:1:1:1:1			=2001:db8:0:1:1:1:1:1
 # RFC 5952 4.2.3
 --in ipv6addr --out ipv6addr 2001:0:0:1:0:0:0:1			 	=2001:0:0:1::1
 --in ipv6addr --out ipv6addr 2001:db8:0:0:1:0:0:1 			=2001:db8::1:0:0:1
@@ -227,6 +275,11 @@ NOPIPETEST--out eui64 00:0:F:6:4:5					=200:fff:fe06:405
 -O hex --forceprefix 24 --printsuffix 1.2.3.4					=04
 -O hex --forceprefix 24 --printprefix 1.2.3.4					=010203
 -O hex -u 192.168.1.1								=C0A80101
+# nibble strings
+-O ipv6addr 1.ip6.arpa								=1000::/4
+-O ipv6addr 1.2.ip6.arpa							=2100::/8
+-O ipv6addr 1.2.3.ip6.arpa							=3210::/12
+-O ipv6addr 1.2.3.4.ip6.arpa							=4321::/16
 # Extraction
 NOPIPETEST--in ipv6 2001:db8::a8bb:ccff:fedd:eeff --out eui64                             =aa:bb:cc:ff:fe:dd:ee:ff
 NOPIPETEST--in ipv6 2001:db8::a8bb:ccff:fedd:eeff --out mac                               =aa:bb:cc:dd:ee:ff
@@ -235,6 +288,17 @@ NOPIPETEST-A addr2cc 3ffe:831f:ce49:7601:8000:efff:af4a:86bf			=IT;DB_IPV6_CC
 NOPIPETEST-A addr2cc 8.8.8.8							=US;DB_IPV4_CC
 NOPIPETEST--addr2cc 3ffe:831f:ce49:7601:8000:efff:af4a:86bf			=IT;DB_IPV6_CC
 NOPIPETEST--addr2cc 8.8.8.8							=US;DB_IPV4_CC
+# revnibble >= 3.1.0
+NOPIPETEST9.b.3.2.9.7.f.1.9.a.e.5.3.8.5.f					=::f583:5ea9:1f79:23b9/64
+NOPIPETEST9.b.3.2.9.7.f.1.9.a.e.5.3.8.5.f --printsuffix				=f583:5ea9:1f79:23b9
+NOPIPETEST0.1.2.3.4.5.6.7.8.9.a.b.c.d.e.f					=::fedc:ba98:7654:3210/64
+NOPIPETEST0.1.2.3.4.5.6.7.8.9.a.b.c.d.e.f.0.1					=::10:fedc:ba98:7654:3210/56
+NOPIPETEST0.1.2.3.4.5.6.7.8.9.a.b.c.d.e.f.a.b					=::ba:fedc:ba98:7654:3210/56
+NOPIPETEST0.1.2.3.4.5.6.7.8.9.a.b.c.d.e.f.a					=::a:fedc:ba98:7654:3210/60
+NOPIPETEST0.1.2.3.4.5.6.7.8.9.a.b.c.d.e.f.a.b.c					=::cba:fedc:ba98:7654:3210/52
+NOPIPETEST0.1.2.3.4.5.6.7.8.9.a.b.c.d.e.f.a.b.c.d				=::dcba:fedc:ba98:7654:3210/48
+NOPIPETEST0.1.2.3.4.5.6.7.8.9.a.b.c.d.e.f.a.b.c.d --printsuffix			=dcba:fedc:ba98:7654:3210
+NOPIPETEST0.1.2.3.4.5.6.7.8.9.a.b.c.d.e.f.a.b.c --printsuffix			=cba:fedc:ba98:7654:3210
 END
 }
 
@@ -245,6 +309,22 @@ cat <<END | grep -v '^#'
 1.2.3.r4									ipv4addr
 2.2.3.4/-1									ipv4addr
 2.2.3.4/33									ipv4addr
+1.2.3.4/									ipv4addr
+1.2.3.4/00									ipv4addr
+0300.0000.0002.0001/33								ipv4addr
+0300.0000.0002.0001.1								ipv4addr
+0500.0000.0002.0001.1								ipv4addr
+320.2.3.4									ipv4addr
+0/00										ipv4addr
+1										ipv4addr
+1.										ipv4addr
+1.2										ipv4addr
+1.2.										ipv4addr
+1.2.3										ipv4addr
+1.2.3.										ipv4addr
+1.2.3.4.5/10									ipv4addr
+/10										ipv4addr
+./10										ipv4addr
 01:23:r5:67:89:01								mac
 2002:102:304::r1								ipv6addr
 2002:102:304::1/-1								ipv6addr
@@ -271,7 +351,7 @@ END
 # Test proper option definitions
 test="test proper option definition"
 echo "INFO  : $test"
-if [ "$verbose" = "1" ]; then
+if $verbose; then
 	./ipv6calc -h
 	retval=$?
 else
@@ -287,7 +367,7 @@ echo "INFO  : $test successful"
 
 test="run 'ipv6calc' version test"
 echo "INFO  : $test"
-if [ "$verbose" = "1" ]; then
+if $verbose; then
 	./ipv6calc -vvv
 	retval=$?
 else
@@ -303,7 +383,7 @@ echo "INFO  : $test successful"
 
 test="run 'ipv6calc' version test in debug mode"
 echo "INFO  : $test"
-if [ "$verbose" = "1" ]; then
+if $verbose; then
 	./ipv6calc -vvv -d -1
 	retval=$?
 else
@@ -319,7 +399,7 @@ echo "INFO  : $test successful"
 
 test="run 'ipv6calc' version help test for feature tokens"
 echo "INFO  : $test"
-if [ "$verbose" = "1" ]; then
+if $verbose; then
 	./ipv6calc -v -h
 	retval=$?
 else
@@ -376,7 +456,7 @@ testscenarios | sed 's/NOPIPETEST//' | while read line; do
 
 	info="INFO  : test './ipv6calc $command' for '$result'"
 	[ -n "$condition" ] && info="$info (condition=$condition)"
-	[ "$verbose" = "1" ] && echo "$info"
+	$verbose && echo "$info"
 
 	# check condition
 	if [ -n "$condition" ]; then
@@ -392,49 +472,89 @@ testscenarios | sed 's/NOPIPETEST//' | while read line; do
 	output="`./ipv6calc -q $command`"
 	retval=$?
 	if [ $retval -ne 0 ]; then
-		[ "$verbose" = "1" ] || echo "$info"
+		$verbose || echo "$info"
 		echo "ERROR: problem executing: ./ipv6calc $command"
 		exit 1
 	fi
 	# Check result
 	if [ "$result" != "*" ]; then
 		if [ "$output" != "$result" ]; then
-			[ "$verbose" = "1" ] || echo "$info"
+			$verbose || echo "$info"
 			echo "ERROR: result '$output' doesn't match: $result"
 			exit 1
 		fi
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
 
+## database dump test
+test="run 'ipv6calc' database dump for IPv4 by CountryCode"
+if ./ipv6calc -v 2>&1 | grep -wq DB_IPV4_DUMP_CC; then
+	echo "INFO  : $test"
+	lines=$(./ipv6calc -q -A dbdump -E ipv4.db.cc=VN | wc -l)
+	if [ $lines -eq 0 ]; then
+		echo "ERROR : $test failed"
+		exit 1
+	fi
+	echo "INFO  : $test successful"
+else
+	echo "NOTICE: $test not executed (feature missing: DB_IPV4_DUMP)"
+fi
 
+test="run 'ipv6calc' database dump for IPv4 by CountryCode incl. 6to4 conversion"
+if ./ipv6calc -v 2>&1 | grep -wq DB_IPV4_DUMP_CC; then
+	echo "INFO  : $test"
+	lines=$(./ipv6calc -q -A dbdump -E ipv4.db.cc=VN -O ipv6to4 --printfulluncompressed | wc -l)
+	if [ $lines -eq 0 ]; then
+		echo "ERROR : $test failed"
+		exit 1
+	fi
+	echo "INFO  : $test successful"
+else
+	echo "NOTICE: $test not executed (feature missing: DB_IPV4_DUMP)"
+fi
+
+test="run 'ipv6calc' database dump for IPv6 by CountryCode"
+if ./ipv6calc -v 2>&1 | grep -wq DB_IPV6_DUMP_CC; then
+	echo "INFO  : $test"
+	lines=$(./ipv6calc -q -A dbdump -E ipv6.db.cc=VN | wc -l)
+	if [ $lines -eq 0 ]; then
+		echo "ERROR : $test failed"
+		exit 1
+	fi
+	echo "INFO  : $test successful"
+else
+	echo "NOTICE: $test not executed (feature missing: DB_IPV6_DUMP)"
+fi
+
+## genprivacyiid
 test="run 'ipv6calc' action 'genprivacyiid'"
 echo "INFO  : $test"
 testscenarios_genprivacyiid | while read in1 in2 out1 out2; do
 	info="INFO  : test './ipv6calc -q -A genprivacyiid $in1 $in2'"
-	[ "$verbose" = "1" ] && echo "$info"
+	$verbose && echo "$info"
 
 	result="`./ipv6calc -q -A genprivacyiid $in1 $in2`"
 	retval=$?
 
 	if [ $retval -ne 0 ]; then
-		[ "$verbose" = "1" ] || echo "$info"
+		$verbose || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
 
 	if [ "$result" != "$out1 $out2" ]; then
-		[ "$verbose" = "1" ] || echo "$info"
+		$verbose || echo "$info"
 		echo "Result is not matching!"
 		echo "Result is      : $result"
 		echo "Result expected: $out1 $out2"
 		exit 1
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
 
 
@@ -443,8 +563,8 @@ echo "INFO  : $test"
 ./ipv6calc -m --in -? | while read inputformat; do
 	if echo $inputformat | grep -q '+'; then
 		info="INFO  : test './ipv6calc -q --in $inputformat \"\" \"\"'"
-		[ "$verbose" = "1" ] && echo "$info"
-		if [ "$verbose" = "1" ]; then
+		$verbose && echo "$info"
+		if $verbose; then
 			./ipv6calc -q --in $inputformat "" ""
 			retval=$?
 		else
@@ -453,8 +573,8 @@ echo "INFO  : $test"
 		fi
 	else
 		info="INFO  : test './ipv6calc -q --in $inputformat \"\"'"
-		[ "$verbose" = "1" ] && echo "$info"
-		if [ "$verbose" = "1" ]; then
+		$verbose && echo "$info"
+		if $verbose; then
 			./ipv6calc -q --in $inputformat ""
 			retval=$?
 		else
@@ -463,13 +583,13 @@ echo "INFO  : $test"
 		fi
 	fi
 	if [ $retval -ne 1 ]; then
-		[ "$verbose" = "1" ] || echo "$info"
+		$verbose || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
 
 
@@ -479,8 +599,8 @@ line="`perl -e 'print "x" x300'`"
 ./ipv6calc -m --in -? | while read inputformat; do
 	if echo $inputformat | grep -q '+'; then
 		info="INFO  : test './ipv6calc -q --in $inputformat \"$line\" \"$line\"'"
-		[ "$verbose" = "1" ] && echo "$info"
-		if [ "$verbose" = "1" ]; then
+		$verbose && echo "$info"
+		if $verbose; then
 			./ipv6calc -q --in $inputformat "$line" "$line"
 			retval=$?
 		else
@@ -489,8 +609,8 @@ line="`perl -e 'print "x" x300'`"
 		fi
 	else
 		info="INFO  : test './ipv6calc -q --in $inputformat \"$line\"'"
-		[ "$verbose" = "1" ] && echo "$info"
-		if [ "$verbose" = "1" ]; then
+		$verbose && echo "$info"
+		if $verbose; then
 			./ipv6calc -q --in $inputformat "$line"
 			retval=$?
 		else
@@ -499,13 +619,13 @@ line="`perl -e 'print "x" x300'`"
 		fi
 	fi
 	if [ $retval -ne 1 ]; then
-		[ "$verbose" = "1" ] || echo "$info"
+		$verbose || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
 
 
@@ -522,8 +642,8 @@ echo "INFO  : $test"
 	esac
 	if echo $inputformat | grep -q '+'; then
 		info="INFO  : test './ipv6calc -q --in $inputformat \"$line\" \"$line\"'"
-		[ "$verbose" = "1" ] && echo "$info"
-		if [ "$verbose" = "1" ]; then
+		$verbose && echo "$info"
+		if $verbose; then
 			./ipv6calc -q --in $inputformat "$line" "$line"
 			retval=$?
 		else
@@ -532,8 +652,8 @@ echo "INFO  : $test"
 		fi
 	else
 		info="INFO  : test './ipv6calc -q --in $inputformat \"$line\"'"
-		[ "$verbose" = "1" ] && echo "$info"
-		if [ "$verbose" = "1" ]; then
+		$verbose && echo "$info"
+		if $verbose; then
 			./ipv6calc -q --in $inputformat "$line"
 			retval=$?
 		else
@@ -542,13 +662,13 @@ echo "INFO  : $test"
 		fi
 	fi
 	if [ $retval -ne 1 ]; then
-		[ "$verbose" = "1" ] || echo "$info"
+		$verbose || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
 
 
@@ -556,17 +676,17 @@ test="run 'ipv6calc' input autodetection tests (good cases)"
 echo "INFO  : $test"
 testscenarios_auto_good | while read input dummy; do
 	info="INFO  : test './ipv6calc -q \"$input\"'"
-	[ "$verbose" = "1" ] && echo "$info"
+	$verbose && echo "$info"
 	./ipv6calc -q "$input" >/dev/null
 	retval=$?
 	if [ $retval -ne 0 ]; then
-		[ "$verbose" = "1" ] || echo "$info"
+		$verbose || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
 
 
@@ -574,8 +694,8 @@ test="run 'ipv6calc' input autodetection tests (bad cases)"
 echo "INFO  : $test"
 testscenarios_auto_bad | while read input dummy; do
 	info="INFO  : test './ipv6calc -q \"$input\"'"
-	[ "$verbose" = "1" ] && echo "$info"
-	if [ "$verbose" = "1" ]; then
+	$verbose && echo "$info"
+	if $verbose; then
 		./ipv6calc -q "$input"
 		retval=$?
 	else
@@ -583,30 +703,30 @@ testscenarios_auto_bad | while read input dummy; do
 		retval=$?
 	fi
 	if [ $retval -eq 0 ]; then
-		[ "$verbose" = "1" ] || echo "$info"
+		$verbose || echo "$info"
 		echo "Error executing 'ipv6calc' ($retval)!"
 		exit 1
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
 
 test="run 'ipv6calc' input tests (good cases)"
 echo "INFO  : $test"
 testscenarios_auto_good | while read input type; do
 	info="INFO  : test './ipv6calc --in $type -q \"$input\"'"
-	[ "$verbose" = "1" ] && echo "$info"
+	$verbose && echo "$info"
 	./ipv6calc --in $type -q "$input" >/dev/null
 	retval=$?
 	if [ $retval -ne 0 ]; then
-		[ "$verbose" = "1" ] || echo "$info"
+		$verbose || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
 
 
@@ -614,18 +734,18 @@ test="run 'ipv6calc' pipe tests (1)"
 echo "INFO  : $test"
 testscenarios_pipe | while IFS="," read input arguments result; do
 	info="INFO  : test 'echo $input | ./ipv6calc $arguments | grep \"^$result\$\"'"
-	[ "$verbose" = "1" ] && echo "$info"
+	$verbose && echo "$info"
 	output=$(echo -e $input | ./ipv6calc $arguments | grep "^$result\$")
 	retval=$?
-	[ "$verbose" = "1" ] && echo "$output"
+	$verbose && echo "$output"
 	if [ $retval -ne 0 ]; then
-		[ "$verbose" = "1" ] || echo "$info"
+		$verbose || echo "$info"
 		echo "Error executing 'ipv6calc' ($retval)!"
 		exit 1
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
 
 
@@ -652,25 +772,25 @@ testscenarios | grep -v "^NOPIPETEST" | while read line; do
 		;;
 	esac
 	info="INFO  : test 'echo $stdin | ./ipv6calc $options | grep \"^$result\$\"'"
-	[ "$verbose" = "1" ] && echo "$info"
+	$verbose && echo "$info"
 	output="`echo -e $stdin | ./ipv6calc $options`"
 	retval=$?
 	if [ $retval -ne 0 ]; then
-		[ "$verbose" = "1" ] || echo "$info"
+		$verbose || echo "$info"
 		echo "Error executing 'ipv6calc' ($retval)!"
 		exit 1
 	fi
 	# Check result
 	if [ "$result" != "*" ]; then
 		if [ "$output" != "$result" ]; then
-			[ "$verbose" = "1" ] || echo "$info"
+			$verbose || echo "$info"
 			echo "Result '$output' doesn't match!"
 			exit 1
 		fi
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
 
 
@@ -679,33 +799,25 @@ echo "INFO  : $test"
 ./ipv6calc -m --in -? | while read inputformat; do
 	if echo $inputformat | grep -q '+'; then
 		info="INFO  : test '8192*x 8192*x | ./ipv6calc -q --in $inputformat"
-		[ "$verbose" = "1" ] && echo "$info"
+		$verbose && echo "$info"
 		output=$(perl -e 'print "x" x8192 . " " . "y" x8192' | ./ipv6calc -q --in $inputformat 2>&1)
 		retval=$?
 	else
 		info="INFO  : test '8192*x | ./ipv6calc -q --in $inputformat"
-		[ "$verbose" = "1" ] && echo "$info"
+		$verbose && echo "$info"
 		output=$(perl -e 'print "x" x8192' | ./ipv6calc -q --in $inputformat 2>&1)
 		retval=$?
 	fi
-	[ "$verbose" = "1" ] && echo "$output"
+	$verbose && echo "$output"
 	if [ $retval -ne 0 -a $retval -ne 1 ]; then
-		[ "$verbose" = "1" ] || echo "$info"
+		$verbose || echo "$info"
 		echo "Error executing 'ipv6calc'!"
 		exit 1
 	fi
-	[ "$verbose" = "1" ] || echo -n "."
+	$verbose || echo -n "."
 done || exit 1
-[ "$verbose" = "1" ] || echo
+$verbose || echo
 echo "INFO  : $test successful"
 
-
-retval=$?
-if [ $retval -eq 0 ]; then
-	echo "INFO  : all tests were successfully done!"
-	exit 0
-else
-	echo "ERROR : tests failed! (code $retval)"
-	exit $retval
-fi
-
+echo "INFO  : all tests were successfully done!"
+exit 0
