@@ -1,20 +1,21 @@
-#!/bin/sh
+#!/usr/bin/env bash
 #
 # Project    : ipv6calc
 # File       : test_ipv6calc_anonymization.sh
-# Version    : $Id: 1c37ffd5f74be11718db1b55ec76532936c7020e $
-# Copyright  : 2013-2019 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: df72b089e5286cdce2cbbdb944b877d840b69cdc $
+# Copyright  : 2013-2021 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test ipv6calc anonymization
 
-verbose=0
+verbose=false
+stoponerror=false
 while getopts "VSh\?" opt; do
 	case $opt in
 	    V)
-		verbose=1
+		verbose=true
 		;;
 	    S)
-		stoponerror=1
+		stoponerror=true
 		;;
 	    *)
 		echo "$0 [-V] [-S]"
@@ -40,6 +41,12 @@ test_list() {
 }
 
 run_anon_tests() {
+	if ! ./ipv6calc -v 2>&1| grep -wq "ANON_ANONYMIZE"; then
+		echo "NOTICE: 'ipv6calc' has not required support for ANON_ANONYMIZE, skip standard tests"
+		! $stoponerror
+		return
+	fi
+
 	test="run 'ipv6calc' anonymization tests"
 	echo "INFO  : $test"
 	test_list | while read input filter; do
@@ -47,7 +54,7 @@ run_anon_tests() {
 			continue
 		fi
 
-		[ "$verbose" = "1" ] && echo "INFO: test './ipv6calc -A anonymize' for: $input"
+		$verbose && echo "INFO: test './ipv6calc -A anonymize' for: $input"
 
 		output="`echo "$input" | ./ipv6calc -q -A anonymize`"
 		retval=$?
@@ -56,15 +63,24 @@ run_anon_tests() {
 			exit 1
 		fi
 
-		[ "$verbose" = "1" ] && echo "INFO  : anonymized: $output"
+		$verbose && echo "INFO  : anonymized: $output"
 
-		type_orig="`./ipv6calc -q -i "$input" -m | grep -a "^IPV._TYPE=" | sed 's/IPV._TYPE=//'`"
-		type_anon="`./ipv6calc -q -i "$output" -m | grep -a "^IPV._TYPE=" | sed 's/IPV._TYPE=//'`"
+		type_orig="`./ipv6calc -q -i "$input" -m --mrtvo IPV._TYPE`"
+		if [ $? -ne 0 ]; then
+			echo "ERROR  : ipv6calc result not 0: ./ipv6calc -q -i "$input" -m"
+			exit 1
+		fi
+
+		type_anon="`./ipv6calc -q -i "$output" -m --mrtvo IPV._TYPE`"
+		if [ $? -ne 0 ]; then
+			echo "ERROR  : ipv6calc result not 0: ./ipv6calc -q -i "$output" -m"
+			exit 1
+		fi
 
 		if [ -z "$type_orig" -a -z "$type_anon" ]; then
 			# fallback EUI*
-			type_orig="`./ipv6calc -q -i "$input" -m | grep -a "^EUI.._TYPE=" | sed 's/EUI.._TYPE=//'`"
-			type_anon="`./ipv6calc -q -i "$output" -m | grep -a "^EUI.._TYPE=" | sed 's/EUI.._TYPE=//'`"
+			type_orig="`./ipv6calc -q -i "$input"  -m --mrtvo EUI.._TYPE`"
+			type_anon="`./ipv6calc -q -i "$output" -m --mrtvo EUI.._TYPE`"
 		fi
 
 		if [ -z "$type_orig" ]; then
@@ -97,21 +113,21 @@ run_anon_tests() {
 		type_anon_compare="$(echo "$type_anon_compare" | perl -p -e 's/(^,|,$)//g')"
 		type_orig_compare="$(echo "$type_orig_compare" | perl -p -e 's/(^,|,$)//g')"
 
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx_TYPE orig: $type_orig_compare"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx_TYPE anon: $type_anon_compare"
+		$verbose && echo "DEBUG : IPVx_TYPE orig: $type_orig_compare"
+		$verbose && echo "DEBUG : IPVx_TYPE anon: $type_anon_compare"
 		# Check result
 		if [ "$type_orig_compare" != "$type_anon_compare" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : IPVx_TYPE not equal for: $input (anonymized: $output)"
 			echo "ERROR : IPVx_TYPE orig: $type_orig_compare"
 			echo "ERROR : IPVx_TYPE anon: $type_anon_compare"
 			exit 1
 		else
-			[ "$verbose" = "1" ] && echo "INFO  : result ok!" || true
+			$verbose && echo "INFO  : result ok!" || true
 		fi
-		[ "$verbose" = "1" ] || echo -n "."
+		$verbose || echo -n "."
 	done || return 1 
-	[ "$verbose" = "1" ] || echo
+	$verbose || echo
 	echo "INFO  : $test successful"
 }
 
@@ -132,25 +148,25 @@ run_anon_options_tests() {
 		fi
 
 		if [ "$result" != "$result_real" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : result doesn't match on command: $command"
 			echo "ERROR : result is      : $result_real"
 			echo "ERROR : result expected: $result"
 			exit 1
 		else
-			[ "$verbose" = "1" ] && echo "INFO  : $command -> test ok" || true
+			$verbose && echo "INFO  : $command -> test ok" || true
 		fi
-		[ "$verbose" = "1" ] || echo -n "."
+		$verbose || echo -n "."
 	done || return 1
-	[ "$verbose" = "1" ] || echo
+	$verbose || echo
 	echo "INFO  : $test successful"
 }
 
 run_anon_options_kp_tests() {
 	if ! ./ipv6calc -v 2>&1| grep -wq "ANON_KEEP-TYPE-ASN-CC"; then
 		echo "NOTICE: 'ipv6calc' has not required support for Anonymization Type-ASN-CountryCode included, skip option kp tests"
-		[ "$stoponerror" = "1" ] && return 1
-		return 0
+		! $stoponerror
+		return
 	fi
 
 	test="run 'ipv6calc' anonymization option kp tests"
@@ -169,15 +185,15 @@ run_anon_options_kp_tests() {
 		fi
 
 		if [ "$result" != "$output" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : result doesn't match on command: $command"
 			echo "ERROR : result is      : $output"
 			echo "ERROR : result expected: $result"
 			exit 1
 		fi
-		[ "$verbose" = "1" ] || echo -n "."
+		$verbose || echo -n "."
 	done || return 1
-	[ "$verbose" = "1" ] || echo
+	$verbose || echo
 	echo "INFO  : $test successful"
 
 	test="run 'ipv6calc' anonymization option kp TYPE/REGISTRY/CC tests"
@@ -187,7 +203,7 @@ run_anon_options_kp_tests() {
 			continue
 		fi
 
-		[ "$verbose" = "1" ] && echo "INFO  : run test with: $input"
+		$verbose && echo "INFO  : run test with: $input"
 
 		output=$(./ipv6calc -q -A anonymize --anonymize-preset kp $input)
 		if [ $? -ne 0 -o -z "$output" ]; then
@@ -195,8 +211,8 @@ run_anon_options_kp_tests() {
 			exit 1
 		fi
 
-		type_orig="`./ipv6calc -m -i -q "$input"  | grep -a "^IPV._TYPE=" | sed 's/IPV._TYPE=//'`"
-		type_anon="`./ipv6calc -m -i -q "$output" | grep -a "^IPV._TYPE=" | sed 's/IPV._TYPE=//'`"
+		type_orig="`./ipv6calc -m -i -q "$input"  --mrtvo IPV._TYPE`"
+		type_anon="`./ipv6calc -m -i -q "$output" --mrtvo IPV._TYPE`"
 
 		if [ -z "$type_orig" ]; then
 			echo "ERROR : something went wrong retrieving IPVx_TYPE for $input"
@@ -223,100 +239,100 @@ run_anon_options_kp_tests() {
 		type_orig_compare="$(echo "$type_orig_compare" | perl -p -e 's/(^,|,$)//g')"
 
 		if [ -z "$type_orig_compare" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : something went wrong reducing IPVx_TYPE for $input"
 			exit 1
 		fi
 		if [ -z "$type_anon_compare" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : something went wrong reducing IPVx_TYPE for $output"
 			exit 1
 		fi
 
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx      orig: $input"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx      anon: $output"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx_TYPE orig: $type_orig_compare"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx_TYPE anon: $type_anon_compare"
+		$verbose && echo "DEBUG : IPVx      orig: $input"
+		$verbose && echo "DEBUG : IPVx      anon: $output"
+		$verbose && echo "DEBUG : IPVx_TYPE orig: $type_orig_compare"
+		$verbose && echo "DEBUG : IPVx_TYPE anon: $type_anon_compare"
 
 		# Check result
 		if [ "$type_orig_compare" != "$type_anon_compare" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : IPVx_TYPE not equal for: $input (anonymized: $output)"
 			echo "ERROR : IPVx_TYPE orig: $type_orig_compare"
 			echo "ERROR : IPVx_TYPE anon: $type_anon_compare"
 			exit 1
 		else
-			[ "$verbose" = "1" ] && echo "Result ok!" || true
+			$verbose && echo "Result ok!" || true
 		fi
 
 		# Registry
-		reg_orig="`./ipv6calc -m -i -q "$input"  | grep -a "^IPV._REGISTRY=" | sed 's/IPV._REGISTRY=//'`"
+		reg_orig="`./ipv6calc -m -i -q "$input"  --mrtvo IPV._REGISTRY`"
 		if echo "$reg_orig" | grep -q LISP; then
 			reg_orig=${reg_orig/(*} # cut lisp details
 		fi
-		reg_anon="`./ipv6calc -m -i -q "$output" | grep -a "^IPV._REGISTRY=" | sed 's/IPV._REGISTRY=//'`"
+		reg_anon="`./ipv6calc -m -i -q "$output" --mrtvo IPV._REGISTRY`"
 
 		if [ -z "$reg_orig" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : something went wrong retrieving IPVx_REGISTRY for $input"
 			exit 1
 		fi
 		if [ -z "$reg_anon" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : something went wrong retrieving IPVx_REGISTRY for $output"
 			exit 1
 		fi
 
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx          orig: $input"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx          anon: $output"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx_REGISTRY orig: $reg_orig"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx_REGISTRY anon: $reg_anon"
+		$verbose && echo "DEBUG : IPVx          orig: $input"
+		$verbose && echo "DEBUG : IPVx          anon: $output"
+		$verbose && echo "DEBUG : IPVx_REGISTRY orig: $reg_orig"
+		$verbose && echo "DEBUG : IPVx_REGISTRY anon: $reg_anon"
 
 		if [ -z "$reg_orig" -a -z "$reg_anon" ]; then
 			# everything is ok, both have no registry
 			true
 		elif [ -z "$reg_orig" -a -n "$reg_anon" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : something went wrong, anon has registry while orig hasn't"
 			exit 1
 		elif [ -n "$reg_orig" -a -z "$reg_anon" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : something went wrong, orig has registry while anon hasn't"
 			exit 1
 		else
 			# Check result
 			if [ "$reg_orig" != "$reg_anon" ]; then
-				[ "$verbose" = "1" ] || echo
+				$verbose || echo
 				echo "ERROR : IPVx_REGISTRY not equal for: $input (anonymized: $output)"
 				echo "ERROR : IPVx_REGISTRY orig: $reg_orig"
 				echo "ERROR : IPVx_REGISTRY anon: $reg_anon"
 				exit 1
 			else
-				[ "$verbose" = "1" ] && echo "Result ok!" || true
+				$verbose && echo "Result ok!" || true
 			fi
 		fi
 
 		# Country Code (optional)
-		cc_orig="`./ipv6calc -m -i -q "$input"  | grep -a "^IPV._COUNTRYCODE=" | sed 's/IPV._COUNTRYCODE=//'`"
-		cc_anon="`./ipv6calc -m -i -q "$output" | grep -a "^IPV._COUNTRYCODE=" | sed 's/IPV._COUNTRYCODE=//'`"
+		cc_orig="`./ipv6calc -m -i -q "$input"  --mrtvo IPV._COUNTRYCODE`"
+		cc_anon="`./ipv6calc -m -i -q "$output" --mrtvo IPV._COUNTRYCODE`"
 
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx             orig: $input"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx             anon: $output"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx_COUNTRYCODE orig: $cc_orig"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx_COUNTRYCODE anon: $cc_anon"
+		$verbose && echo "DEBUG : IPVx             orig: $input"
+		$verbose && echo "DEBUG : IPVx             anon: $output"
+		$verbose && echo "DEBUG : IPVx_COUNTRYCODE orig: $cc_orig"
+		$verbose && echo "DEBUG : IPVx_COUNTRYCODE anon: $cc_anon"
 
 		if [ -z "$cc_orig" -a -z "$cc_anon" ]; then
 			# everything is ok, both have no CC
 			true
 		elif [ -z "$cc_orig" -a -n "$cc_anon" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : IPVx_COUNTRYCODE not equal for: $input (anonymized: $output)"
 			echo "ERROR : IPVx_COUNTRYCODE orig: $cc_orig"
 			echo "ERROR : IPVx_COUNTRYCODE anon: $cc_anon"
 			echo "ERROR : something went wrong, anon has country code while orig hasn't"
 			exit 1
 		elif [ -n "$cc_orig" -a -z "$cc_anon" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : IPVx_COUNTRYCODE not equal for: $input (anonymized: $output)"
 			echo "ERROR : IPVx_COUNTRYCODE orig: $cc_orig"
 			echo "ERROR : IPVx_COUNTRYCODE anon: $cc_anon"
@@ -325,42 +341,42 @@ run_anon_options_kp_tests() {
 		else
 			# Check result
 			if [ "$cc_orig" != "$cc_anon" ]; then
-				[ "$verbose" = "1" ] || echo
+				$verbose || echo
 				echo "ERROR : IPVx_COUNTRYCODE not equal for: $input (anonymized: $output)"
 				echo "ERROR : IPVx_COUNTRYCODE orig: $cc_orig"
 				echo "ERROR : IPVx_COUNTRYCODE anon: $cc_anon"
 				exit 1
 			else
-				[ "$verbose" = "1" ] && echo "Result ok!" || true
+				$verbose && echo "Result ok!" || true
 			fi
 		fi
-		[ "$verbose" = "1" ] || echo -n "."
+		$verbose || echo -n "+"
 
 		# ASN (optional)
-		if echo "${type_orig//,/ }" | grep -w ipv4 | grep -w lisp >/dev/null; then
-			# skip ASN on IPv4+LISP
+		if echo "${type_orig//,/ }" | grep -Eqw "(lisp|ipv4|iid-includes-ipv4)"; then
+			# skip ASN on IPv4+LISP or IID includes IPv4
 			continue
 		fi
-		asn_orig="`./ipv6calc -m -i -q "$input"  | grep -a "^IPV._AS_NUM=" | sed 's/IPV._AS_NUM=//'`"
-		asn_anon="`./ipv6calc -m -i -q "$output" | grep -a "^IPV._AS_NUM=" | sed 's/IPV._AS_NUM=//'`"
+		asn_orig="`./ipv6calc -m -i -q "$input"  --mrtvo IPV._AS_NUM`"
+		asn_anon="`./ipv6calc -m -i -q "$output" --mrtvo IPV._AS_NUM`"
 
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx     orig: $input"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx     anon: $output"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx_AS_NUM orig: $asn_orig"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx_AS_NUM anon: $asn_anon"
+		$verbose && echo "DEBUG : IPVx     orig: $input"
+		$verbose && echo "DEBUG : IPVx     anon: $output"
+		$verbose && echo "DEBUG : IPVx_AS_NUM orig: $asn_orig"
+		$verbose && echo "DEBUG : IPVx_AS_NUM anon: $asn_anon"
 
 		if [ -z "$asn_orig" -a -z "$asn_anon" ]; then
 			# everything is ok, both have no AS_NUM
 			true
 		elif [ -z "$asn_orig" -a -n "$asn_anon" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : IPVx_AS_NUM not equal for: $input (anonymized: $output)"
 			echo "ERROR : IPVx_AS_NUM orig: $asn_orig"
 			echo "ERROR : IPVx_AS_NUM anon: $asn_anon"
 			echo "ERROR : something went wrong, anon has AS_NUM code while orig hasn't"
 			exit 1
 		elif [ -n "$asn_orig" -a -z "$asn_anon" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : IPVx_AS_NUM not equal for: $input (anonymized: $output)"
 			echo "ERROR : IPVx_AS_NUM orig: $asn_orig"
 			echo "ERROR : IPVx_AS_NUM anon: $asn_anon"
@@ -369,26 +385,26 @@ run_anon_options_kp_tests() {
 		else
 			# Check result
 			if [ "$asn_orig" != "$asn_anon" ]; then
-				[ "$verbose" = "1" ] || echo
+				$verbose || echo
 				echo "ERROR : IPVx_AS_NUM not equal for: $input (anonymized: $output)"
 				echo "ERROR : IPVx_AS_NUM orig: $asn_orig"
 				echo "ERROR : IPVx_AS_NUM anon: $asn_anon"
 				exit 1
 			else
-				[ "$verbose" = "1" ] && echo "Result ok!" || true
+				$verbose && echo "Result ok!" || true
 			fi
 		fi
-		[ "$verbose" = "1" ] || echo -n "."
+		$verbose || echo -n "."
 	done || return 1
-	[ "$verbose" = "1" ] || echo
+	$verbose || echo
 	echo "INFO  : $test successful"
 }
 
 run_anon_options_kg_tests() {
 	if ! ./ipv6calc -v 2>&1| grep -wq "ANON_KEEP-TYPE-GEONAMEID"; then
 		echo "NOTICE: 'ipv6calc' has not required support for Anonymization Type-GeonameID included, skip option kg tests"
-		[ "$stoponerror" = "1" ] && return 1
-		return 0
+		! $stoponerror
+		return
 	fi
 
 	test="run 'ipv6calc' anonymization option kg TYPE/GEONAMEID tests"
@@ -398,7 +414,7 @@ run_anon_options_kg_tests() {
 			continue
 		fi
 
-		[ "$verbose" = "1" ] && echo "INFO  : run test with: $input"
+		$verbose && echo "INFO  : run test with: $input"
 
 		output=$(./ipv6calc -q -A anonymize --anonymize-preset kg $input)
 		if [ $? -ne 0 -o -z "$output" ]; then
@@ -406,8 +422,8 @@ run_anon_options_kg_tests() {
 			exit 1
 		fi
 
-		type_orig="`./ipv6calc -m -i -q "$input"  | grep -a "^IPV._TYPE=" | sed 's/IPV._TYPE=//'`"
-		type_anon="`./ipv6calc -m -i -q "$output" | grep -a "^IPV._TYPE=" | sed 's/IPV._TYPE=//'`"
+		type_orig="`./ipv6calc -m -i -q "$input"  --mrtvo IPV._TYPE`"
+		type_anon="`./ipv6calc -m -i -q "$output" --mrtvo IPV._TYPE`"
 
 		if [ -z "$type_orig" ]; then
 			echo "ERROR : something went wrong retrieving IPVx_TYPE for $input"
@@ -434,100 +450,100 @@ run_anon_options_kg_tests() {
 		type_orig_compare="$(echo "$type_orig_compare" | perl -p -e 's/(^,|,$)//g')"
 
 		if [ -z "$type_orig_compare" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : something went wrong reducing IPVx_TYPE for $input"
 			exit 1
 		fi
 		if [ -z "$type_anon_compare" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : something went wrong reducing IPVx_TYPE for $output"
 			exit 1
 		fi
 
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx      orig: $input"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx      anon: $output"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx_TYPE orig: $type_orig_compare"
-		[ "$verbose" = "1" ] && echo "DEBUG : IPVx_TYPE anon: $type_anon_compare"
+		$verbose && echo "DEBUG : IPVx      orig: $input"
+		$verbose && echo "DEBUG : IPVx      anon: $output"
+		$verbose && echo "DEBUG : IPVx_TYPE orig: $type_orig_compare"
+		$verbose && echo "DEBUG : IPVx_TYPE anon: $type_anon_compare"
 
 		# Check result
 		if [ "$type_orig_compare" != "$type_anon_compare" ]; then
-			[ "$verbose" = "1" ] || echo
+			$verbose || echo
 			echo "ERROR : IPVx_TYPE not equal for: $input (anonymized: $output)"
 			echo "ERROR : IPVx_TYPE orig: $type_orig_compare"
 			echo "ERROR : IPVx_TYPE anon: $type_anon_compare"
 			exit 1
 		else
-			[ "$verbose" = "1" ] && echo "Result ok!" || true
+			$verbose && echo "Result ok!" || true
 		fi
 
 		# Registry (only in case of LISP)
-		reg_orig="`./ipv6calc -m -i -q "$input"  | grep -a "^IPV._REGISTRY=" | sed 's/IPV._REGISTRY=//'`"
+		reg_orig="`./ipv6calc -m -i -q "$input" --mrtvo IPV._REGISTRY`"
 		if echo "$reg_orig" | grep -q LISP; then
 			reg_orig=${reg_orig/(*} # cut lisp details
 
-			reg_anon="`./ipv6calc -m -i -q "$output" | grep -a "^IPV._REGISTRY=" | sed 's/IPV._REGISTRY=//'`"
+			reg_anon="`./ipv6calc -m -i -q "$output" --mrtvo IPV._REGISTRY`"
 
 			if [ -z "$reg_orig" ]; then
-				[ "$verbose" = "1" ] || echo
+				$verbose || echo
 				echo "ERROR : something went wrong retrieving IPVx_REGISTRY for $input"
 				exit 1
 			fi
 			if [ -z "$reg_anon" ]; then
-				[ "$verbose" = "1" ] || echo
+				$verbose || echo
 				echo "ERROR : something went wrong retrieving IPVx_REGISTRY for $output"
 				exit 1
 			fi
 
-			[ "$verbose" = "1" ] && echo "DEBUG : IPVx          orig: $input"
-			[ "$verbose" = "1" ] && echo "DEBUG : IPVx          anon: $output"
-			[ "$verbose" = "1" ] && echo "DEBUG : IPVx_REGISTRY orig: $reg_orig"
-			[ "$verbose" = "1" ] && echo "DEBUG : IPVx_REGISTRY anon: $reg_anon"
+			$verbose && echo "DEBUG : IPVx          orig: $input"
+			$verbose && echo "DEBUG : IPVx          anon: $output"
+			$verbose && echo "DEBUG : IPVx_REGISTRY orig: $reg_orig"
+			$verbose && echo "DEBUG : IPVx_REGISTRY anon: $reg_anon"
 
 			if [ -z "$reg_orig" -a -z "$reg_anon" ]; then
 				# everything is ok, both have no registry
 				true
 			elif [ -z "$reg_orig" -a -n "$reg_anon" ]; then
-				[ "$verbose" = "1" ] || echo
+				$verbose || echo
 				echo "ERROR : something went wrong, anon has registry while orig hasn't"
 				exit 1
 			elif [ -n "$reg_orig" -a -z "$reg_anon" ]; then
-				[ "$verbose" = "1" ] || echo
+				$verbose || echo
 				echo "ERROR : something went wrong, orig has registry while anon hasn't"
 				exit 1
 			else
 				# Check result
 				if [ "$reg_orig" != "$reg_anon" ]; then
-					[ "$verbose" = "1" ] || echo
+					$verbose || echo
 					echo "ERROR : IPVx_REGISTRY not equal for: $input (anonymized: $output)"
 					echo "ERROR : IPVx_REGISTRY orig: $reg_orig"
 					echo "ERROR : IPVx_REGISTRY anon: $reg_anon"
 					exit 1
 				else
-					[ "$verbose" = "1" ] && echo "Result ok!" || true
+					$verbose && echo "Result ok!" || true
 				fi
 			fi
 		else
 			# GeonameID
-			gi_orig="`./ipv6calc -m -i -q "$input"  | grep -a "^IPV._GEONAME_ID=" | sed 's/IPV._GEONAME_ID=//'`"
-			gi_anon="`./ipv6calc -m -i -q "$output" | grep -a "^IPV._GEONAME_ID=" | sed 's/IPV._GEONAME_ID=//'`"
+			gi_orig="`./ipv6calc -m -i -q "$input"  --mrtvo IPV._GEONAME_ID`"
+			gi_anon="`./ipv6calc -m -i -q "$output" --mrtvo IPV._GEONAME_ID`"
 
-			[ "$verbose" = "1" ] && echo "DEBUG : IPVx             orig: $input"
-			[ "$verbose" = "1" ] && echo "DEBUG : IPVx             anon: $output"
-			[ "$verbose" = "1" ] && echo "DEBUG : IPVx_GEONAME_ID   orig: $gi_orig"
-			[ "$verbose" = "1" ] && echo "DEBUG : IPVx_GEONAME_ID   anon: $gi_anon"
+			$verbose && echo "DEBUG : IPVx             orig: $input"
+			$verbose && echo "DEBUG : IPVx             anon: $output"
+			$verbose && echo "DEBUG : IPVx_GEONAME_ID   orig: $gi_orig"
+			$verbose && echo "DEBUG : IPVx_GEONAME_ID   anon: $gi_anon"
 
 			if [ -z "$gi_orig" -a -z "$gi_anon" ]; then
 				# everything is ok, both have no CC
 				true
 			elif [ -z "$gi_orig" -a -n "$gi_anon" ]; then
-				[ "$verbose" = "1" ] || echo
+				$verbose || echo
 				echo "ERROR : IPVx_GEONAME_ID not equal for: $input (anonymized: $output)"
 				echo "ERROR : IPVx_GEONAME_ID orig: $gi_orig"
 				echo "ERROR : IPVx_GEONAME_ID anon: $gi_anon"
 				echo "ERROR : something went wrong, anon has GeonameID while orig hasn't"
 				exit 1
 			elif [ -n "$gi_orig" -a -z "$gi_anon" ]; then
-				[ "$verbose" = "1" ] || echo
+				$verbose || echo
 				echo "ERROR : IPVx_GEONAME_ID not equal for: $input (anonymized: $output)"
 				echo "ERROR : IPVx_GEONAME_ID orig: $gi_orig"
 				echo "ERROR : IPVx_GEONAME_ID anon: $gi_anon"
@@ -536,37 +552,39 @@ run_anon_options_kg_tests() {
 			else
 				# Check result
 				if [ "$gi_orig" != "$gi_anon" ]; then
-					[ "$verbose" = "1" ] || echo
+					$verbose || echo
 					echo "ERROR : IPVx_GEONAME_ID not equal for: $input (anonymized: $output)"
 					echo "ERROR : IPVx_GEONAME_ID orig: $gi_orig"
 					echo "ERROR : IPVx_GEONAME_ID anon: $gi_anon"
 					exit 1
 				else
-					[ "$verbose" = "1" ] && echo "Result ok!" || true
+					$verbose && echo "Result ok!" || true
 				fi
 			fi
 
-			# GeonameID Type
-			gi_type_orig="`./ipv6calc -m -i -q "$input"  | grep -a "^IPV._GEONAME_ID_TYPE=" | sed 's/IPV._GEONAME_ID_TYPE=//'`"
-			gi_type_anon="`./ipv6calc -m -i -q "$output" | grep -a "^IPV._GEONAME_ID_TYPE=" | sed 's/IPV._GEONAME_ID_TYPE=//'`"
+			$verbose || echo -n "+"
 
-			[ "$verbose" = "1" ] && echo "DEBUG : IPVx             orig: $input"
-			[ "$verbose" = "1" ] && echo "DEBUG : IPVx             anon: $output"
-			[ "$verbose" = "1" ] && echo "DEBUG : IPVx_GEONAME_ID_TYPE   orig: $gi_type_orig"
-			[ "$verbose" = "1" ] && echo "DEBUG : IPVx_GEONAME_ID_TYPE   anon: $gi_type_anon"
+			# GeonameID Type
+			gi_type_orig="`./ipv6calc -m -i -q "$input"  --mrtvo IPV._GEONAME_ID_TYPE`"
+			gi_type_anon="`./ipv6calc -m -i -q "$output" --mrtvo IPV._GEONAME_ID_TYPE`"
+
+			$verbose && echo "DEBUG : IPVx             orig: $input"
+			$verbose && echo "DEBUG : IPVx             anon: $output"
+			$verbose && echo "DEBUG : IPVx_GEONAME_ID_TYPE   orig: $gi_type_orig"
+			$verbose && echo "DEBUG : IPVx_GEONAME_ID_TYPE   anon: $gi_type_anon"
 
 			if [ -z "$gi_type_orig" -a -z "$gi_type_anon" ]; then
 				# everything is ok, both have no CC
 				true
 			elif [ -z "$gi_type_orig" -a -n "$gi_type_anon" ]; then
-				[ "$verbose" = "1" ] || echo
+				$verbose || echo
 				echo "ERROR : IPVx_GEONAME_ID_TYPE not equal for: $input (anonymized: $output)"
 				echo "ERROR : IPVx_GEONAME_ID_TYPE orig: $gi_type_orig"
 				echo "ERROR : IPVx_GEONAME_ID_TYPE anon: $gi_type_anon"
 				echo "ERROR : something went wrong, anon has GeonameID while orig hasn't"
 				exit 1
 			elif [ -n "$gi_type_orig" -a -z "$gi_type_anon" ]; then
-				[ "$verbose" = "1" ] || echo
+				$verbose || echo
 				echo "ERROR : IPVx_GEONAME_ID_TYPE not equal for: $input (anonymized: $output)"
 				echo "ERROR : IPVx_GEONAME_ID_TYPE orig: $gi_type_orig"
 				echo "ERROR : IPVx_GEONAME_ID_TYPE anon: $gi_type_anon"
@@ -575,19 +593,19 @@ run_anon_options_kg_tests() {
 			else
 				# Check result
 				if [ "$gi_type_orig" != "$gi_type_anon" ]; then
-					[ "$verbose" = "1" ] || echo
+					$verbose || echo
 					echo "ERROR : IPVx_GEONAME_ID_TYPE not equal for: $input (anonymized: $output)"
 					echo "ERROR : IPVx_GEONAME_ID_TYPE orig: $gi_type_orig"
 					echo "ERROR : IPVx_GEONAME_ID_TYPE anon: $gi_type_anon"
 					exit 1
 				else
-					[ "$verbose" = "1" ] && echo "Result ok!" || true
+					$verbose && echo "Result ok!" || true
 				fi
 			fi
 		fi
-		[ "$verbose" = "1" ] || echo -n "."
+		$verbose || echo -n "."
 	done || return 1
-	[ "$verbose" = "1" ] || echo
+	$verbose || echo
 	echo "INFO  : $test successful"
 }
 
