@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calchelp.c
- * Version    : $Id: edf60c73d38d204b0a27193aa26e8493fc6535cb $
- * Copyright  : 2002-2019 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 153b6bdb37131ef610a462bb9db1e9a46af29569 $
+ * Copyright  : 2002-2021 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Help library
@@ -19,14 +19,13 @@
 #include "config.h"
 
 #include "libieee.h"
-#include "databases/lib/libipv6calc_db_wrapper.h"
-#include "databases/lib/libipv6calc_db_wrapper_GeoIP.h"
-#include "databases/lib/libipv6calc_db_wrapper_GeoIP2.h"
-#include "databases/lib/libipv6calc_db_wrapper_IP2Location.h"
-#include "databases/lib/libipv6calc_db_wrapper_DBIP.h"
-#include "databases/lib/libipv6calc_db_wrapper_DBIP2.h"
-#include "databases/lib/libipv6calc_db_wrapper_BuiltIn.h"
-#include "databases/lib/libipv6calc_db_wrapper_External.h"
+
+#include "libipv6calc_db_wrapper.h"
+#include "libipv6calc_db_wrapper_GeoIP2.h"
+#include "libipv6calc_db_wrapper_IP2Location.h"
+#include "libipv6calc_db_wrapper_DBIP2.h"
+#include "libipv6calc_db_wrapper_BuiltIn.h"
+#include "libipv6calc_db_wrapper_External.h"
 
 
 /* to be defined in each application */
@@ -79,7 +78,7 @@ void printhelp_inputtypes(const uint32_t formatoptions) {
 	};
 
 	/* look for longest type definition */
-	for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatstrings); j++) {
+	for (j = 0; j < ipv6calc_formatstrings_entries; j++) {
 		if (strlen(ipv6calc_formatstrings[j].token) > maxlen) {
 			maxlen = strlen(ipv6calc_formatstrings[j].token);
 		};
@@ -101,11 +100,11 @@ void printhelp_inputtypes(const uint32_t formatoptions) {
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) fprintf(stderr, "\n Available input types:\n");
 
 	/* run through matrix */
-	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatmatrix); i++) {
+	for (i = 0; i < ipv6calc_formatmatrix_entries; i++) {
 		DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Row %d: %08x - %08x", i, (unsigned int) ipv6calc_formatmatrix[i][0], (unsigned int) ipv6calc_formatmatrix[i][1]);
 		if (ipv6calc_formatmatrix[i][1] != 0) {
 			/* available for input, look for name now */
-			for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatstrings); j++) {
+			for (j = 0; j < ipv6calc_formatstrings_entries; j++) {
 				DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Format-Row %d: %08x - %s - %s", j, (unsigned int) ipv6calc_formatstrings[j].number, ipv6calc_formatstrings[j].token, ipv6calc_formatstrings[j].explanation);
 				if (ipv6calc_formatstrings[j].number == ipv6calc_formatmatrix[i][0]) {
 					if ((formatoptions & FORMATOPTION_machinereadable) == 0) {	
@@ -134,7 +133,7 @@ void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoption
 	};
 
 	/* look for longest type definition */
-	for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatstrings); j++) {
+	for (j = 0; j < ipv6calc_formatstrings_entries; j++) {
 		if (strlen(ipv6calc_formatstrings[j].token) > maxlen) {
 			maxlen = strlen(ipv6calc_formatstrings[j].token);
 		};
@@ -162,10 +161,10 @@ void printhelp_outputtypes(const uint32_t inputtype, const uint32_t formatoption
 	};
 
 	/* run through matrix */
-	for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatstrings); j++) {
+	for (j = 0; j < ipv6calc_formatstrings_entries; j++) {
 		DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Format-Row %d: %08x - %s - %s", j, (unsigned int) ipv6calc_formatstrings[j].number, ipv6calc_formatstrings[j].token, ipv6calc_formatstrings[j].explanation);
 
-		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_formatmatrix); i++) {
+		for (i = 0; i < ipv6calc_formatmatrix_entries; i++) {
 			if ( (inputtype & ~ (FORMAT_auto | FORMAT_any) ) != 0 ) {
 				if (ipv6calc_formatmatrix[i][0] != inputtype) {
 					/* skip */
@@ -207,7 +206,7 @@ void printhelp_actiontypes(const uint32_t formatoptions, const struct option lon
 	};
 
 	/* look for longest type definition */
-	for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_actionstrings); j++) {
+	for (j = 0; j < ipv6calc_actionstrings_entries; j++) {
 		if (strlen(ipv6calc_actionstrings[j].token) > maxlen) {
 			maxlen = strlen(ipv6calc_actionstrings[j].token);
 		};
@@ -231,7 +230,7 @@ void printhelp_actiontypes(const uint32_t formatoptions, const struct option lon
 
 	if ((formatoptions & FORMATOPTION_machinereadable) == 0) fprintf(stderr, "\n Available action types:\n");
 
-	for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_actionstrings); j++) {
+	for (j = 0; j < ipv6calc_actionstrings_entries; j++) {
 		DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Action-Row %d: %08x - %s - %s", j, (unsigned int) ipv6calc_actionstrings[j].number, ipv6calc_actionstrings[j].token, ipv6calc_actionstrings[j].explanation);
 
 		if ((formatoptions & FORMATOPTION_machinereadable) == 0) {
@@ -245,7 +244,7 @@ void printhelp_actiontypes(const uint32_t formatoptions, const struct option lon
 				};
 
 				/* search for defined options */
-				for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_actionoptionmap); i++) {
+				for (i = 0; i < ipv6calc_actionoptionmap_entries; i++) {
 					DEBUGPRINT_WA(DEBUG_ipv6calcoptions, "Option %d", i)
 
 					if (ipv6calc_actionstrings[j].number == ipv6calc_actionoptionmap[i][0]) {
@@ -342,35 +341,25 @@ void printhelp_common(const uint32_t help_features) {
 		fprintf(stderr, "\n");
 		fprintf(stderr, "  [--db-mmdb-lib       <file>      ] : MaxMindDB library file (default: %s)\n", mmdb_lib_file);
 #endif
+
 #ifdef SUPPORT_GEOIP2
 		fprintf(stderr, "\n");
-		fprintf(stderr, "  [--disable-geoip2                ] : GeoIP (MaxMindDB) support disabled\n");
-		fprintf(stderr, "  [--db-geoip2-disable             ] : GeoIP (MaxMindDB) support disabled\n");
-		fprintf(stderr, "  [--db-geoip2-dir      <directory>] : GeoIP (MaxMindDB) database directory (default: %s)\n", geoip2_db_dir);
+		fprintf(stderr, "  [--disable-geoip2                ] : GeoIP(MaxMindDB) support disabled\n");
+		fprintf(stderr, "  [--db-geoip2-disable             ] : GeoIP(MaxMindDB) support disabled\n");
+		fprintf(stderr, "  [--db-geoip2-dir      <directory>] : GeoIP(MaxMindDB) database directory (default: %s)\n", geoip2_db_dir);
 #endif
+
 #ifdef SUPPORT_DBIP2
 		fprintf(stderr, "\n");
-		fprintf(stderr, "  [--disable-dbip2                 ] : db-ip.com (MaxMindDB) support disabled\n");
-		fprintf(stderr, "  [--db-dbip2-disable              ] : db-ip.com (MaxMindDB) support disabled\n");
-		fprintf(stderr, "  [--db-dbip2-dir       <directory>] : db-ip.com (MaxMindDB) database directory (default: %s)\n", dbip2_db_dir);
-		fprintf(stderr, "  [--db-dbip2-only-type <TYPE>]      : db-ip.com (MaxMindDB) database only selected type (1-%d)\n", DBIP_DB_MAX);
+		fprintf(stderr, "  [--disable-dbip2                 ] : db-ip.com(MaxMindDB) support disabled\n");
+		fprintf(stderr, "  [--db-dbip2-disable              ] : db-ip.com(MaxMindDB) support disabled\n");
+		fprintf(stderr, "  [--db-dbip2-dir       <directory>] : db-ip.com(MaxMindDB) database directory (default: %s)\n", dbip2_db_dir);
+		fprintf(stderr, "  [--db-dbip2-only-type <TYPE>]      : db-ip.com(MaxMindDB) database only selected type (1-%d)\n", DBIP2_DB_MAX);
 		fprintf(stderr, "  [--db-dbip2-comm-to-free-switch-min-delta-months <MONTHS>]:\n");
 		fprintf(stderr, "     switch from COMM to FREE databases if possible and delta more than %d months (0=disabled)\n", dbip2_db_comm_to_free_switch_min_delta_months);
 #endif
 	};
 
-	if ((help_features & IPV6CALC_HELP_DBIP) != 0) {
-#ifdef SUPPORT_DBIP
-		fprintf(stderr, "\n");
-		fprintf(stderr, "  [--disable-dbip                  ] : db-ip.com support disabled\n");
-		fprintf(stderr, "  [--db-dbip-disable               ] : db-ip.com support disabled\n");
-		fprintf(stderr, "  [--db-dbip-dir        <directory>] : db-ip.com database directory (default: %s)\n", dbip_db_dir);
-		fprintf(stderr, "  [--db-dbip-only-type <TYPE>]       : db-ip.com database only selected type (1-%d)\n", DBIP_DB_MAX);
-		fprintf(stderr, "  [--db-dbip-comm-to-free-switch-min-delta-months <MONTHS>]:\n");
-		fprintf(stderr, "     switch from COMM to FREE databases if possible and delta more than %d months (0=disabled)\n", dbip_db_comm_to_free_switch_min_delta_months);
-#endif
-	};
-
 	if ((help_features & IPV6CALC_HELP_EXTERNAL) != 0) {
 #ifdef SUPPORT_EXTERNAL
 		fprintf(stderr, "\n");
@@ -387,7 +376,7 @@ void printhelp_common(const uint32_t help_features) {
 		fprintf(stderr, "  [--db-builtin-disable            ] : BuiltIn support disabled\n");
 #endif
 
-#if defined SUPPORT_EXTERNAL || defined SUPPORT_DBIP || defined SUPPORT_GEOIP || SUPPORT_IP2LOCATION
+#if defined SUPPORT_EXTERNAL || defined SUPPORT_DBIP2 || defined SUPPORT_GEOIP2 || SUPPORT_IP2LOCATION
 		fprintf(stderr, "\n");
 		fprintf(stderr, "  [--db-priorization <entry1>[:...]] : Database priorization order list (overwrites default)\n");
 		fprintf(stderr, "                                         colon separated:");
@@ -399,6 +388,13 @@ void printhelp_common(const uint32_t help_features) {
 #endif
 	};
 
+	fprintf(stderr, "\n");
+	fprintf(stderr, " Hint: all long options can be predefined from environment by using\n");
+	fprintf(stderr, "  prefix: IPV6CALC_ and  conversion: '-' -> '_' and lowercase -> uppercase\n");
+	fprintf(stderr, "  example for options with values   : --db-dbip2-dir=<DIR>  ->  environment: IPV6CALC_DB_DBIP2_DIR=<DIR>\n");
+	fprintf(stderr, "  example for options without values: --db-dbip2-disable    ->  environment: IPV6CALC_DB_DBIP2_DISABLE=1\n");
+	fprintf(stderr, "                                                                              on|off|0|1 is supported\n");
+
 	fprintf(stderr, "\n");
 	return;
 };
@@ -521,6 +517,16 @@ static void printhelp_output_revnibble_arpa(void) {
 	fprintf(stderr, "  3ffe:ffff:100:f101::1/64\n    -> 1.0.1.f.0.0.1.0.0.0.4.0.e.f.f.3.ip6.arpa.\n");
 };
 
+static void printhelp_input_revnibbles(void) {
+	fprintf(stderr, " Print reverse nibble format (used in DNS) as IPv6 address, e.g.\n");
+	fprintf(stderr, "  1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.8.b.d.0.1.0.0.2.ip6.arpa.\n    -> 2001:db8::1/128\n");
+	fprintf(stderr, "  8.b.d.0.1.0.0.2.ip6.arpa.\n    -> 2001:db8::/32\n");
+	fprintf(stderr, "  8.b.d.0.1.0.0.2.ip6.arpa. --printprefix\n    -> 2001:db8\n");
+	fprintf(stderr, "  1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0\n    -> ::1/64\n");
+	fprintf(stderr, "  1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0 --printsuffix\n    -> 0:0:0:1\n");
+};
+
+
 static void printhelp_output_ifinet6void(void) {
 	fprintf(stderr, " Print a given IPv6 address to same format shown in Linux /proc/net/if_inet6:\n");
 	fprintf(stderr, "  3ffe:ffff:100:f101::1    -> 3ffeffff0100f1010000000000000001 00\n");
@@ -528,7 +534,15 @@ static void printhelp_output_ifinet6void(void) {
 };
 
 static void printhelp_output_ipv4addr(void) {
-	fprintf(stderr, " Print an IPv4 address\n");
+	fprintf(stderr, " Print an IPv4 address, depending on format options:\n");
+	fprintf(stderr, "  Uncompressed, e.g.\n");
+	fprintf(stderr, "   1.2.0.0 -> 1.2.0.0\n");
+	fprintf(stderr, "   1.2.0.  -> 1.2.0.0\n");
+	fprintf(stderr, "   1.2     -> 1.2.0.0\n");
+	fprintf(stderr, "  Compressed, e.g.\n");
+	fprintf(stderr, "   1.2.0.0 -> 1.2\n");
+	fprintf(stderr, "  Octal, e.g.\n");
+	fprintf(stderr, "   192.0.2.1 -> 0300.0000.0002.0001\n");
 };
 
 static void printhelp_output_revipv4(void) {
@@ -560,13 +574,15 @@ static void printhelp_output_ouitype(void) {
 };
 
 static void printhelp_output_octal(void) {
-	fprintf(stderr, " Print octal representation of a given IPv6 address:\n");
+	fprintf(stderr, " Print octal representation of a given IP address:\n");
 	fprintf(stderr, "  (useful for djbdns/tinydns)\n");
-	fprintf(stderr, "  3ffe:ffff::1 ->\n    \\77\\376\\377\\377\\0\\0\\0\\0\\0\\0\\0\\0\\0\\0\\0\\1\n");
-	fprintf(stderr, "  --printfulluncompressed 3ffe:ffff::1 ->\n    \\077\\376\\377\\377\\000\\000\\000\\000\\000\\000\\000\\000\\000\\000\\000\\001\n");
+	fprintf(stderr, "  3ffe:ffff::1 -> \\077\\0376\\0377\\0377\\00\\00\\00\\00\\00\\00\\00\\00\\00\\00\\00\\01\n");
+	fprintf(stderr, "  --printfulluncompressed 3ffe:ffff::1 -> \\0077\\0376\\0377\\0377\\0000\\0000\\0000\\0000\\0000\\0000\\0000\\0000\\0000\\0000\\0000\\0001\n");
+	fprintf(stderr, "  192.0.2.1 -> \\0300\\00\\02\\01\n");
+	fprintf(stderr, "  --printfulluncompressed 192.0.2.1 -> \\0300\\0000\\0002\\0001\n");
 };
 
-void printhelp_output_dispatcher(const uint32_t outputtype) {
+void printhelp_output_dispatcher(const uint32_t outputtype, const uint32_t inputtype) {
 	int i, j;
 
 	printversion();
@@ -639,12 +655,21 @@ void printhelp_output_dispatcher(const uint32_t outputtype) {
 			break;
 			
 		default:
-			fprintf(stderr, " Examples currently missing...!\n");
+			switch (inputtype) {
+				case FORMAT_revnibbles_int:
+				case FORMAT_revnibbles_arpa:
+					printhelp_input_revnibbles();
+					break;
+
+				default:
+					fprintf(stderr, " Examples currently missing... (output type)!\n");
+					break;
+			};
 			break;
 	};
 	
 	/* looking for outtype */
-	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_outputformatoptionmap); i++) {
+	for (i = 0; i < ipv6calc_outputformatoptionmap_entries; i++) {
 		if (outputtype == ipv6calc_outputformatoptionmap[i][0]) {
 			if (ipv6calc_outputformatoptionmap[i][1] == 0) {
 				fprintf(stderr, " No format options supported\n");
@@ -657,7 +682,7 @@ void printhelp_output_dispatcher(const uint32_t outputtype) {
 			fprintf(stderr, " Available format options:\n");
 
 			/* run through format options */
-			for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_formatoptionstrings); j++) {
+			for (j = 0; j < ipv6calc_formatoptionstrings_entries; j++) {
 				if ((ipv6calc_outputformatoptionmap[i][1] & ipv6calc_formatoptionstrings[j].number) != 0) {
 					fprintf(stderr, "  %s: %s\n", ipv6calc_formatoptionstrings[j].token, ipv6calc_formatoptionstrings[j].explanation);
 				};
@@ -687,10 +712,14 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			
 		case ACTION_ipv4_to_6to4addr:
 			fprintf(stderr, "  Convert IPv4 to 6to4 prefix / extract IPv4 from 6to4 prefix\n");
-			fprintf(stderr, "   ipv6calc -A conv6to4 192.0.2.1\n");
-			fprintf(stderr, "    2002:c000:201::\n");
-			fprintf(stderr, "   ipv6calc -A conv6to4 2002:c000:201::\n");
-			fprintf(stderr, "    192.0.2.1\n");
+			fprintf(stderr, "   ipv6calc -A conv6to4 192.0.2.1          -> 2002:c000:201::\n");
+			fprintf(stderr, "   ipv6calc -A conv6to4 192.0.2.1/24       -> 2002:c000:200::/40\n");
+			fprintf(stderr, "   ipv6calc -A conv6to4 192.0.2.0/24       -> 2002:c000:200::/40\n");
+			fprintf(stderr, "   ipv6calc -A conv6to4 2002:c000:201::    -> 192.0.2.1\n");
+			fprintf(stderr, "   ipv6calc -A conv6to4 2002:c000:201::/40 -> 192.0.2.0/24\n");
+			fprintf(stderr, "\n");
+			fprintf(stderr, "  See '-O ipv4 -h' or '-O ipv6 -h' for optional output modifications\n");
+			fprintf(stderr, "  Can also be used in PIPE mode to convert a list of IP addresses/networks\n");
 			break;
 
 		case ACTION_ipv4_to_nat64:
@@ -717,17 +746,17 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			fprintf(stderr, "   --anonymize-paranoid\n");
 			fprintf(stderr, "\n");
 			fprintf(stderr, "  Supported methods [--anonymize-method METHOD]:\n");
-			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_anon_methods); i++) {
+			for (i = 0; i < ipv6calc_anon_methods_entries; i++) {
 				fprintf(stderr, "   %-10s: %s\n", ipv6calc_anon_methods[i].name, ipv6calc_anon_methods[i].description);
 			};
 			fprintf(stderr, "\n");
 
 			fprintf(stderr, "  Available presets (shortcut names) [--anonymize-preset|ap PRESET-NAME]:\n");
 
-			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_anon_set_list); i++) {
+			for (i = 0; i < ipv6calc_anon_set_list_entries; i++) {
 				snprintf(method_name, sizeof(method_name), "%s", "unknown"); // default
 
-				for (j = 0; j < MAXENTRIES_ARRAY(ipv6calc_anon_methods); j++) {
+				for (j = 0; j < ipv6calc_anon_methods_entries; j++) {
 					if (ipv6calc_anon_methods[j].method == ipv6calc_anon_set_list[i].method) {
 						snprintf(method_name, sizeof(method_name), "%s", ipv6calc_anon_methods[j].name);
 						break;
@@ -771,14 +800,14 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			fprintf(stderr, "\n");
 			fprintf(stderr, "  IPv6 address filter tokens:\n");
 			fprintf(stderr, "   ipv6 ");
-			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++ ) {
+			for (i = 0; i < ipv6calc_ipv6addrtypestrings_entries; i++ ) {
 				fprintf(stderr, " %s", ipv6calc_ipv6addrtypestrings[i].token);
 			};
 			fprintf(stderr, "\n");
 			fprintf(stderr, "\n");
 			fprintf(stderr, "  IPv4 address filter tokens:\n");
 			fprintf(stderr, "   ipv4 ");
-			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv4addrtypestrings); i++ ) {
+			for (i = 0; i < ipv6calc_ipv4addrtypestrings_entries; i++ ) {
 				fprintf(stderr, " %s", ipv6calc_ipv4addrtypestrings[i].token);
 			};
 			fprintf(stderr, "\n");
@@ -788,7 +817,7 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			fprintf(stderr, "   [^][ipv4.|ipv6.]db.asn=<ASN>|unknown (Autonomous System Number)\n");
 			fprintf(stderr, "   [^][ipv4.|ipv6.]db.reg=<REGISTRY>\n");
 			fprintf(stderr, "    Registry tokens:");
-			for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_registries); i++ ) {
+			for (i = 0; i < ipv6calc_registries_entries; i++ ) {
 				fprintf(stderr, " %s", ipv6calc_registries[i].token);
 			};
 			fprintf(stderr, "\n");
@@ -855,6 +884,16 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 			fprintf(stderr, "  -- (no-usable-database)\n");
 			fprintf(stderr, "\n");
 			break;
+
+		case ACTION_db_dump:
+			fprintf(stderr, "  Dump (supported) databases depending on selector\n");
+			fprintf(stderr, "   ipv6calc -A dbdump -E <FILTER> [--print-ipset <SETNAME>]\n");
+			fprintf(stderr, "\n");
+			fprintf(stderr, "  See '-O ipv4 -h' or '-O ipv6 -h' for optional output modifications\n");
+			fprintf(stderr, "  See '-E -h' for available filter\n");
+			fprintf(stderr, "  Use '-q --print-ipset <SETNAME>' to generate 'ipset restore' compatible format\n");
+			fprintf(stderr, "  Supported and autoselected database: External (only so far)\n");
+			break;
 	};
 };
 
@@ -865,7 +904,7 @@ void printhelp_action_dispatcher(const uint32_t action, const int embedded) {
 
 /* display features in verbose mode */
 void ipv6calc_print_features_verbose(const int level_verbose) {
-	char string[NI_MAXHOST] = "";
+	char string[IPV6CALC_STRING_MAX] = "";
 
 	libipv6calc_db_wrapper_capabilities(string, sizeof(string));
 	fprintf(stderr, "Capabilities: %s\n\n", string);
@@ -901,6 +940,14 @@ void ipv6calc_print_features_verbose(const int level_verbose) {
 	fprintf(stderr, "\n\n");
 #endif
 
+#if defined ENABLE_OPENSSL_EVP_MD5
+	fprintf(stderr, "Linked MD5 implemenation: OpenSSL EVP MD5\n\n");
+#endif
+#if defined ENABLE_OPENSSL_MD5
+	fprintf(stderr, "Linked MD5 implemenation: OpenSSL legacy MD5\n\n");
+#endif
+
+
 	fprintf(stderr, "Compiled: %s  %s\n\n", __DATE__, __TIME__);
 
 	libipv6calc_db_wrapper_print_features_verbose(level_verbose);
