@@ -1,14 +1,12 @@
-#!/bin/sh
+#!/usr/bin/env bash
 #
 # Project    : ipv6calc
 # File       : test_mod_ipv6calc.sh
-# Version    : $Id: 1e0bfde5ad44f37bc229f14f9ba9b6e27055c2b0 $
-# Copyright  : 2015-2019 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: 93b822bf836bc917dff05f41ac23b91af8f7ce78 $
+# Copyright  : 2015-2021 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc conversions
 
-verbose=0
-
 for BIN_PS in /bin/ps /usr/bin/ps; do
 	if [ -x "$BIN_PS" ]; then
 		break
@@ -103,10 +101,8 @@ create_apache_root_and_start() {
 	fi
 
 	## disable databases by option
-	[ "$disable_geoip" = "1" ]       && perl -pi -e 's/#(ipv6calcOption\s+db-geoip-disable\s+yes)$/$1/g' $dir_base/conf.d/ipv6calc.conf
 	[ "$disable_geoip2" = "1" ]      && perl -pi -e 's/#(ipv6calcOption\s+db-geoip2-disable\s+yes)$/$1/g' $dir_base/conf.d/ipv6calc.conf
 	[ "$disable_ip2location" = "1" ] && perl -pi -e 's/#(ipv6calcOption\s+db-ip2location-disable\s+yes)$/$1/g' $dir_base/conf.d/ipv6calc.conf
-	[ "$disable_dbip" = "1" ]        && perl -pi -e 's/#(ipv6calcOption\s+db-dbip-disable\s+yes)$/$1/g' $dir_base/conf.d/ipv6calc.conf
 	[ "$disable_dbip2" = "1" ]       && perl -pi -e 's/#(ipv6calcOption\s+db-dbip2-disable\s+yes)$/$1/g' $dir_base/conf.d/ipv6calc.conf
 	[ "$disable_external" = "1" ]    && perl -pi -e 's/#(ipv6calcOption\s+db-external-disable\s+yes)$/$1/g' $dir_base/conf.d/ipv6calc.conf
 
@@ -116,6 +112,10 @@ create_apache_root_and_start() {
 	[ "$action_gid" = "0" ]    && perl -pi -e 's/(ipv6calcActionGeonameid\s+).*$/$1 off/g'   $dir_base/conf.d/ipv6calc.conf
 	[ "$action_anon" = "0" ]   && perl -pi -e 's/(ipv6calcActionAnonymize\s+).*$/$1 off/g'   $dir_base/conf.d/ipv6calc.conf
 
+	[ "$config_passive" = "1" ]   && perl -pi -e 's/(ipv6calcDefaultActive\s+).*$/$1 off/g'   $dir_base/conf.d/ipv6calc.conf
+	[ "$config_passive" != "1" -a "$config_environment" = "1" ]   && echo "SetEnv ipv6calcPassive" >>$dir_base/conf.d/ipv6calc.conf
+	[ "$config_passive" = "1" -a "$config_environment" = "1" ]   && echo "SetEnv ipv6calcActive" >>$dir_base/conf.d/ipv6calc.conf
+
 
 	echo "INFO  : start httpd with ServerRoot $dir_base"
 	/usr/sbin/httpd -X -e info -d $dir_base &
@@ -233,18 +233,34 @@ exec_request() {
 		curl -g -s "http://$1:8080/" >/dev/null
 		if [ $? -ne 0 ]; then
 			echo "ERROR : curl request to $1:8080 failed"
-			exit 1
+			return 1
 		fi
 
 		echo "INFO  : access log entry"
 		tail -1 $dir_base/logs/access_log
 
-		if [ -f "$dir_base/logs/access_anon_log" ]; then
+		if [ -f "$dir_base/logs/access_anon_log" -a -s "$dir_base/logs/access_anon_log" ]; then
 			echo "INFO  : anonymized access log entry"
-			tail -1 $dir_base/logs/access_anon_log
+			log_anon=$(tail -1 $dir_base/logs/access_anon_log)
+			echo "$log_anon"
+			if [ "$config_passive" = "1" -a "$config_environment" != "1" ]; then
+				if echo "$log_anon" | grep -q "PbD"; then
+					echo "INFO  : anonymized access log entry is containing 'PdD' (OK)"
+				else
+					echo "ERROR : anonymized access log entry is not containing 'PdD'"
+					return 1
+				fi
+			elif [ "$config_passive" != "1" -a "$config_environment" = "1" ]; then
+				if echo "$log_anon" | grep -q "PbE"; then
+					echo "INFO  : anonymized access log entry is containing 'PbE' (OK)"
+				else
+					echo "ERROR : anonymized access log entry is not containing 'PbE'"
+					return 1
+				fi
+			fi
 		else
-			echo "ERROR : anonymized access log missing"
-			exit 1
+			echo "ERROR : anonymized access log missing or empty"
+			return 1
 		fi
 
 		echo "INFO  : error log entry"
@@ -312,6 +328,9 @@ $(basename "$0") [<options>] [-S|-K|-W]
 	-I	disable action GeonameID
 	-N	disable action Anonymization
 
+	-P	disable 'ipv6calcDefaultActive'
+	-E	keep 'ipv6calcDefaultActive', but set environment
+
 	-b <base directory
 
 	-a <address>	disable autoretrievement of local IP, use given one instead
@@ -320,7 +339,7 @@ END
 }
 
 #### Options
-while getopts "IDGrACRNca:fSKWb:mlgideh\?" opt; do
+while getopts "EPIDGrACRNca:fSKWb:mlgideh\?" opt; do
 	case $opt in
 	    b)
 		if [ -d "$OPTARG" ]; then
@@ -342,7 +361,7 @@ while getopts "IDGrACRNca:fSKWb:mlgideh\?" opt; do
 		debug_config=1
 		;;
 	    g)
-		disable_geoip=1
+		echo "NOTICE: support removed for GeoIP(legacy): $opt"
 		;;
 	    G)
 		disable_geoip2=1
@@ -351,7 +370,7 @@ while getopts "IDGrACRNca:fSKWb:mlgideh\?" opt; do
 		disable_ip2location=1
 		;;
 	    d)
-		disable_dbip=1
+		echo "NOTICE: support removed for db-ip.com(BerkeleyDB): $opt"
 		;;
 	    D)
 		disable_dbip2=1
@@ -386,6 +405,12 @@ while getopts "IDGrACRNca:fSKWb:mlgideh\?" opt; do
 	    N)
 		action_anon="0"
 		;;
+	    P)
+		config_passive="1"
+		;;
+	    E)
+		config_environment="1"
+		;;
 	    r)
 		repeat=1
 		;;
